#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BelongMerchantInfoDTO import BelongMerchantInfoDTO
from alipay.aop.api.domain.UserInformation import UserInformation
from alipay.aop.api.domain.DiscountInfoDataDTO import DiscountInfoDataDTO
from alipay.aop.api.domain.EnviromentalInfoDTO import EnviromentalInfoDTO
from alipay.aop.api.domain.GoodExpirationListDTO import GoodExpirationListDTO
from alipay.aop.api.domain.GreenCupsDTO import GreenCupsDTO
from alipay.aop.api.domain.ItemOrderInfoDTO import ItemOrderInfoDTO
from alipay.aop.api.domain.OrderLogisticsInformationRequestDTO import OrderLogisticsInformationRequestDTO
from alipay.aop.api.domain.OrderGoodsDTO import OrderGoodsDTO


class ReceiptOrderDTO(object):

    def __init__(self):
        self._alipay_uid = None
        self._amount = None
        self._belong_merchant_info = None
        self._borrow_time = None
        self._buyer_info = None
        self._currency = None
        self._discount_amount = None
        self._discount_info_list = None
        self._environmental_info = None
        self._good_expiration_list = None
        self._green_cups_list = None
        self._invoice_entry = None
        self._is_alipay_ticket = None
        self._item_order_list = None
        self._location = None
        self._logistics_info_list = None
        self._merchant_name = None
        self._order_create_time = None
        self._order_goods_list = None
        self._order_link = None
        self._order_modified_time = None
        self._order_pay_time = None
        self._order_type = None
        self._out_biz_no = None
        self._pay_amount = None
        self._pay_type = None
        self._shop_address = None
        self._shop_contract = None
        self._shop_name = None
        self._shop_type = None
        self._terminal_id = None
        self._trade_no = None
        self._trade_type = None

    @property
    def alipay_uid(self):
        return self._alipay_uid

    @alipay_uid.setter
    def alipay_uid(self, value):
        self._alipay_uid = value
    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def belong_merchant_info(self):
        return self._belong_merchant_info

    @belong_merchant_info.setter
    def belong_merchant_info(self, value):
        if isinstance(value, BelongMerchantInfoDTO):
            self._belong_merchant_info = value
        else:
            self._belong_merchant_info = BelongMerchantInfoDTO.from_alipay_dict(value)
    @property
    def borrow_time(self):
        return self._borrow_time

    @borrow_time.setter
    def borrow_time(self, value):
        self._borrow_time = value
    @property
    def buyer_info(self):
        return self._buyer_info

    @buyer_info.setter
    def buyer_info(self, value):
        if isinstance(value, UserInformation):
            self._buyer_info = value
        else:
            self._buyer_info = UserInformation.from_alipay_dict(value)
    @property
    def currency(self):
        return self._currency

    @currency.setter
    def currency(self, value):
        self._currency = value
    @property
    def discount_amount(self):
        return self._discount_amount

    @discount_amount.setter
    def discount_amount(self, value):
        self._discount_amount = value
    @property
    def discount_info_list(self):
        return self._discount_info_list

    @discount_info_list.setter
    def discount_info_list(self, value):
        if isinstance(value, list):
            self._discount_info_list = list()
            for i in value:
                if isinstance(i, DiscountInfoDataDTO):
                    self._discount_info_list.append(i)
                else:
                    self._discount_info_list.append(DiscountInfoDataDTO.from_alipay_dict(i))
    @property
    def environmental_info(self):
        return self._environmental_info

    @environmental_info.setter
    def environmental_info(self, value):
        if isinstance(value, list):
            self._environmental_info = list()
            for i in value:
                if isinstance(i, EnviromentalInfoDTO):
                    self._environmental_info.append(i)
                else:
                    self._environmental_info.append(EnviromentalInfoDTO.from_alipay_dict(i))
    @property
    def good_expiration_list(self):
        return self._good_expiration_list

    @good_expiration_list.setter
    def good_expiration_list(self, value):
        if isinstance(value, list):
            self._good_expiration_list = list()
            for i in value:
                if isinstance(i, GoodExpirationListDTO):
                    self._good_expiration_list.append(i)
                else:
                    self._good_expiration_list.append(GoodExpirationListDTO.from_alipay_dict(i))
    @property
    def green_cups_list(self):
        return self._green_cups_list

    @green_cups_list.setter
    def green_cups_list(self, value):
        if isinstance(value, list):
            self._green_cups_list = list()
            for i in value:
                if isinstance(i, GreenCupsDTO):
                    self._green_cups_list.append(i)
                else:
                    self._green_cups_list.append(GreenCupsDTO.from_alipay_dict(i))
    @property
    def invoice_entry(self):
        return self._invoice_entry

    @invoice_entry.setter
    def invoice_entry(self, value):
        self._invoice_entry = value
    @property
    def is_alipay_ticket(self):
        return self._is_alipay_ticket

    @is_alipay_ticket.setter
    def is_alipay_ticket(self, value):
        self._is_alipay_ticket = value
    @property
    def item_order_list(self):
        return self._item_order_list

    @item_order_list.setter
    def item_order_list(self, value):
        if isinstance(value, list):
            self._item_order_list = list()
            for i in value:
                if isinstance(i, ItemOrderInfoDTO):
                    self._item_order_list.append(i)
                else:
                    self._item_order_list.append(ItemOrderInfoDTO.from_alipay_dict(i))
    @property
    def location(self):
        return self._location

    @location.setter
    def location(self, value):
        self._location = value
    @property
    def logistics_info_list(self):
        return self._logistics_info_list

    @logistics_info_list.setter
    def logistics_info_list(self, value):
        if isinstance(value, list):
            self._logistics_info_list = list()
            for i in value:
                if isinstance(i, OrderLogisticsInformationRequestDTO):
                    self._logistics_info_list.append(i)
                else:
                    self._logistics_info_list.append(OrderLogisticsInformationRequestDTO.from_alipay_dict(i))
    @property
    def merchant_name(self):
        return self._merchant_name

    @merchant_name.setter
    def merchant_name(self, value):
        self._merchant_name = value
    @property
    def order_create_time(self):
        return self._order_create_time

    @order_create_time.setter
    def order_create_time(self, value):
        self._order_create_time = value
    @property
    def order_goods_list(self):
        return self._order_goods_list

    @order_goods_list.setter
    def order_goods_list(self, value):
        if isinstance(value, list):
            self._order_goods_list = list()
            for i in value:
                if isinstance(i, OrderGoodsDTO):
                    self._order_goods_list.append(i)
                else:
                    self._order_goods_list.append(OrderGoodsDTO.from_alipay_dict(i))
    @property
    def order_link(self):
        return self._order_link

    @order_link.setter
    def order_link(self, value):
        self._order_link = value
    @property
    def order_modified_time(self):
        return self._order_modified_time

    @order_modified_time.setter
    def order_modified_time(self, value):
        self._order_modified_time = value
    @property
    def order_pay_time(self):
        return self._order_pay_time

    @order_pay_time.setter
    def order_pay_time(self, value):
        self._order_pay_time = value
    @property
    def order_type(self):
        return self._order_type

    @order_type.setter
    def order_type(self, value):
        self._order_type = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def pay_amount(self):
        return self._pay_amount

    @pay_amount.setter
    def pay_amount(self, value):
        self._pay_amount = value
    @property
    def pay_type(self):
        return self._pay_type

    @pay_type.setter
    def pay_type(self, value):
        self._pay_type = value
    @property
    def shop_address(self):
        return self._shop_address

    @shop_address.setter
    def shop_address(self, value):
        self._shop_address = value
    @property
    def shop_contract(self):
        return self._shop_contract

    @shop_contract.setter
    def shop_contract(self, value):
        self._shop_contract = value
    @property
    def shop_name(self):
        return self._shop_name

    @shop_name.setter
    def shop_name(self, value):
        self._shop_name = value
    @property
    def shop_type(self):
        return self._shop_type

    @shop_type.setter
    def shop_type(self, value):
        self._shop_type = value
    @property
    def terminal_id(self):
        return self._terminal_id

    @terminal_id.setter
    def terminal_id(self, value):
        self._terminal_id = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value
    @property
    def trade_type(self):
        return self._trade_type

    @trade_type.setter
    def trade_type(self, value):
        self._trade_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.alipay_uid:
            if hasattr(self.alipay_uid, 'to_alipay_dict'):
                params['alipay_uid'] = self.alipay_uid.to_alipay_dict()
            else:
                params['alipay_uid'] = self.alipay_uid
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.belong_merchant_info:
            if hasattr(self.belong_merchant_info, 'to_alipay_dict'):
                params['belong_merchant_info'] = self.belong_merchant_info.to_alipay_dict()
            else:
                params['belong_merchant_info'] = self.belong_merchant_info
        if self.borrow_time:
            if hasattr(self.borrow_time, 'to_alipay_dict'):
                params['borrow_time'] = self.borrow_time.to_alipay_dict()
            else:
                params['borrow_time'] = self.borrow_time
        if self.buyer_info:
            if hasattr(self.buyer_info, 'to_alipay_dict'):
                params['buyer_info'] = self.buyer_info.to_alipay_dict()
            else:
                params['buyer_info'] = self.buyer_info
        if self.currency:
            if hasattr(self.currency, 'to_alipay_dict'):
                params['currency'] = self.currency.to_alipay_dict()
            else:
                params['currency'] = self.currency
        if self.discount_amount:
            if hasattr(self.discount_amount, 'to_alipay_dict'):
                params['discount_amount'] = self.discount_amount.to_alipay_dict()
            else:
                params['discount_amount'] = self.discount_amount
        if self.discount_info_list:
            if isinstance(self.discount_info_list, list):
                for i in range(0, len(self.discount_info_list)):
                    element = self.discount_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.discount_info_list[i] = element.to_alipay_dict()
            if hasattr(self.discount_info_list, 'to_alipay_dict'):
                params['discount_info_list'] = self.discount_info_list.to_alipay_dict()
            else:
                params['discount_info_list'] = self.discount_info_list
        if self.environmental_info:
            if isinstance(self.environmental_info, list):
                for i in range(0, len(self.environmental_info)):
                    element = self.environmental_info[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.environmental_info[i] = element.to_alipay_dict()
            if hasattr(self.environmental_info, 'to_alipay_dict'):
                params['environmental_info'] = self.environmental_info.to_alipay_dict()
            else:
                params['environmental_info'] = self.environmental_info
        if self.good_expiration_list:
            if isinstance(self.good_expiration_list, list):
                for i in range(0, len(self.good_expiration_list)):
                    element = self.good_expiration_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.good_expiration_list[i] = element.to_alipay_dict()
            if hasattr(self.good_expiration_list, 'to_alipay_dict'):
                params['good_expiration_list'] = self.good_expiration_list.to_alipay_dict()
            else:
                params['good_expiration_list'] = self.good_expiration_list
        if self.green_cups_list:
            if isinstance(self.green_cups_list, list):
                for i in range(0, len(self.green_cups_list)):
                    element = self.green_cups_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.green_cups_list[i] = element.to_alipay_dict()
            if hasattr(self.green_cups_list, 'to_alipay_dict'):
                params['green_cups_list'] = self.green_cups_list.to_alipay_dict()
            else:
                params['green_cups_list'] = self.green_cups_list
        if self.invoice_entry:
            if hasattr(self.invoice_entry, 'to_alipay_dict'):
                params['invoice_entry'] = self.invoice_entry.to_alipay_dict()
            else:
                params['invoice_entry'] = self.invoice_entry
        if self.is_alipay_ticket:
            if hasattr(self.is_alipay_ticket, 'to_alipay_dict'):
                params['is_alipay_ticket'] = self.is_alipay_ticket.to_alipay_dict()
            else:
                params['is_alipay_ticket'] = self.is_alipay_ticket
        if self.item_order_list:
            if isinstance(self.item_order_list, list):
                for i in range(0, len(self.item_order_list)):
                    element = self.item_order_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.item_order_list[i] = element.to_alipay_dict()
            if hasattr(self.item_order_list, 'to_alipay_dict'):
                params['item_order_list'] = self.item_order_list.to_alipay_dict()
            else:
                params['item_order_list'] = self.item_order_list
        if self.location:
            if hasattr(self.location, 'to_alipay_dict'):
                params['location'] = self.location.to_alipay_dict()
            else:
                params['location'] = self.location
        if self.logistics_info_list:
            if isinstance(self.logistics_info_list, list):
                for i in range(0, len(self.logistics_info_list)):
                    element = self.logistics_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.logistics_info_list[i] = element.to_alipay_dict()
            if hasattr(self.logistics_info_list, 'to_alipay_dict'):
                params['logistics_info_list'] = self.logistics_info_list.to_alipay_dict()
            else:
                params['logistics_info_list'] = self.logistics_info_list
        if self.merchant_name:
            if hasattr(self.merchant_name, 'to_alipay_dict'):
                params['merchant_name'] = self.merchant_name.to_alipay_dict()
            else:
                params['merchant_name'] = self.merchant_name
        if self.order_create_time:
            if hasattr(self.order_create_time, 'to_alipay_dict'):
                params['order_create_time'] = self.order_create_time.to_alipay_dict()
            else:
                params['order_create_time'] = self.order_create_time
        if self.order_goods_list:
            if isinstance(self.order_goods_list, list):
                for i in range(0, len(self.order_goods_list)):
                    element = self.order_goods_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.order_goods_list[i] = element.to_alipay_dict()
            if hasattr(self.order_goods_list, 'to_alipay_dict'):
                params['order_goods_list'] = self.order_goods_list.to_alipay_dict()
            else:
                params['order_goods_list'] = self.order_goods_list
        if self.order_link:
            if hasattr(self.order_link, 'to_alipay_dict'):
                params['order_link'] = self.order_link.to_alipay_dict()
            else:
                params['order_link'] = self.order_link
        if self.order_modified_time:
            if hasattr(self.order_modified_time, 'to_alipay_dict'):
                params['order_modified_time'] = self.order_modified_time.to_alipay_dict()
            else:
                params['order_modified_time'] = self.order_modified_time
        if self.order_pay_time:
            if hasattr(self.order_pay_time, 'to_alipay_dict'):
                params['order_pay_time'] = self.order_pay_time.to_alipay_dict()
            else:
                params['order_pay_time'] = self.order_pay_time
        if self.order_type:
            if hasattr(self.order_type, 'to_alipay_dict'):
                params['order_type'] = self.order_type.to_alipay_dict()
            else:
                params['order_type'] = self.order_type
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.pay_amount:
            if hasattr(self.pay_amount, 'to_alipay_dict'):
                params['pay_amount'] = self.pay_amount.to_alipay_dict()
            else:
                params['pay_amount'] = self.pay_amount
        if self.pay_type:
            if hasattr(self.pay_type, 'to_alipay_dict'):
                params['pay_type'] = self.pay_type.to_alipay_dict()
            else:
                params['pay_type'] = self.pay_type
        if self.shop_address:
            if hasattr(self.shop_address, 'to_alipay_dict'):
                params['shop_address'] = self.shop_address.to_alipay_dict()
            else:
                params['shop_address'] = self.shop_address
        if self.shop_contract:
            if hasattr(self.shop_contract, 'to_alipay_dict'):
                params['shop_contract'] = self.shop_contract.to_alipay_dict()
            else:
                params['shop_contract'] = self.shop_contract
        if self.shop_name:
            if hasattr(self.shop_name, 'to_alipay_dict'):
                params['shop_name'] = self.shop_name.to_alipay_dict()
            else:
                params['shop_name'] = self.shop_name
        if self.shop_type:
            if hasattr(self.shop_type, 'to_alipay_dict'):
                params['shop_type'] = self.shop_type.to_alipay_dict()
            else:
                params['shop_type'] = self.shop_type
        if self.terminal_id:
            if hasattr(self.terminal_id, 'to_alipay_dict'):
                params['terminal_id'] = self.terminal_id.to_alipay_dict()
            else:
                params['terminal_id'] = self.terminal_id
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        if self.trade_type:
            if hasattr(self.trade_type, 'to_alipay_dict'):
                params['trade_type'] = self.trade_type.to_alipay_dict()
            else:
                params['trade_type'] = self.trade_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ReceiptOrderDTO()
        if 'alipay_uid' in d:
            o.alipay_uid = d['alipay_uid']
        if 'amount' in d:
            o.amount = d['amount']
        if 'belong_merchant_info' in d:
            o.belong_merchant_info = d['belong_merchant_info']
        if 'borrow_time' in d:
            o.borrow_time = d['borrow_time']
        if 'buyer_info' in d:
            o.buyer_info = d['buyer_info']
        if 'currency' in d:
            o.currency = d['currency']
        if 'discount_amount' in d:
            o.discount_amount = d['discount_amount']
        if 'discount_info_list' in d:
            o.discount_info_list = d['discount_info_list']
        if 'environmental_info' in d:
            o.environmental_info = d['environmental_info']
        if 'good_expiration_list' in d:
            o.good_expiration_list = d['good_expiration_list']
        if 'green_cups_list' in d:
            o.green_cups_list = d['green_cups_list']
        if 'invoice_entry' in d:
            o.invoice_entry = d['invoice_entry']
        if 'is_alipay_ticket' in d:
            o.is_alipay_ticket = d['is_alipay_ticket']
        if 'item_order_list' in d:
            o.item_order_list = d['item_order_list']
        if 'location' in d:
            o.location = d['location']
        if 'logistics_info_list' in d:
            o.logistics_info_list = d['logistics_info_list']
        if 'merchant_name' in d:
            o.merchant_name = d['merchant_name']
        if 'order_create_time' in d:
            o.order_create_time = d['order_create_time']
        if 'order_goods_list' in d:
            o.order_goods_list = d['order_goods_list']
        if 'order_link' in d:
            o.order_link = d['order_link']
        if 'order_modified_time' in d:
            o.order_modified_time = d['order_modified_time']
        if 'order_pay_time' in d:
            o.order_pay_time = d['order_pay_time']
        if 'order_type' in d:
            o.order_type = d['order_type']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'pay_amount' in d:
            o.pay_amount = d['pay_amount']
        if 'pay_type' in d:
            o.pay_type = d['pay_type']
        if 'shop_address' in d:
            o.shop_address = d['shop_address']
        if 'shop_contract' in d:
            o.shop_contract = d['shop_contract']
        if 'shop_name' in d:
            o.shop_name = d['shop_name']
        if 'shop_type' in d:
            o.shop_type = d['shop_type']
        if 'terminal_id' in d:
            o.terminal_id = d['terminal_id']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        if 'trade_type' in d:
            o.trade_type = d['trade_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserGroupbuyingSyncModel(object):

    def __init__(self):
        self._group_expire = None
        self._group_id = None
        self._havana_id = None
        self._item_id = None

    @property
    def group_expire(self):
        return self._group_expire

    @group_expire.setter
    def group_expire(self, value):
        self._group_expire = value
    @property
    def group_id(self):
        return self._group_id

    @group_id.setter
    def group_id(self, value):
        self._group_id = value
    @property
    def havana_id(self):
        return self._havana_id

    @havana_id.setter
    def havana_id(self, value):
        self._havana_id = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.group_expire:
            if hasattr(self.group_expire, 'to_alipay_dict'):
                params['group_expire'] = self.group_expire.to_alipay_dict()
            else:
                params['group_expire'] = self.group_expire
        if self.group_id:
            if hasattr(self.group_id, 'to_alipay_dict'):
                params['group_id'] = self.group_id.to_alipay_dict()
            else:
                params['group_id'] = self.group_id
        if self.havana_id:
            if hasattr(self.havana_id, 'to_alipay_dict'):
                params['havana_id'] = self.havana_id.to_alipay_dict()
            else:
                params['havana_id'] = self.havana_id
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserGroupbuyingSyncModel()
        if 'group_expire' in d:
            o.group_expire = d['group_expire']
        if 'group_id' in d:
            o.group_id = d['group_id']
        if 'havana_id' in d:
            o.havana_id = d['havana_id']
        if 'item_id' in d:
            o.item_id = d['item_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFinanceQuotationQuotetradeSymbolBatchqueryModel(object):

    def __init__(self):
        self._symbols = None

    @property
    def symbols(self):
        return self._symbols

    @symbols.setter
    def symbols(self, value):
        if isinstance(value, list):
            self._symbols = list()
            for i in value:
                self._symbols.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.symbols:
            if isinstance(self.symbols, list):
                for i in range(0, len(self.symbols)):
                    element = self.symbols[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.symbols[i] = element.to_alipay_dict()
            if hasattr(self.symbols, 'to_alipay_dict'):
                params['symbols'] = self.symbols.to_alipay_dict()
            else:
                params['symbols'] = self.symbols
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFinanceQuotationQuotetradeSymbolBatchqueryModel()
        if 'symbols' in d:
            o.symbols = d['symbols']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ActivityRuleDetail(object):

    def __init__(self):
        self._rule_amount = None
        self._rule_discount = None
        self._rule_period = None
        self._rule_period_unit = None
        self._rule_times = None

    @property
    def rule_amount(self):
        return self._rule_amount

    @rule_amount.setter
    def rule_amount(self, value):
        self._rule_amount = value
    @property
    def rule_discount(self):
        return self._rule_discount

    @rule_discount.setter
    def rule_discount(self, value):
        self._rule_discount = value
    @property
    def rule_period(self):
        return self._rule_period

    @rule_period.setter
    def rule_period(self, value):
        self._rule_period = value
    @property
    def rule_period_unit(self):
        return self._rule_period_unit

    @rule_period_unit.setter
    def rule_period_unit(self, value):
        self._rule_period_unit = value
    @property
    def rule_times(self):
        return self._rule_times

    @rule_times.setter
    def rule_times(self, value):
        self._rule_times = value


    def to_alipay_dict(self):
        params = dict()
        if self.rule_amount:
            if hasattr(self.rule_amount, 'to_alipay_dict'):
                params['rule_amount'] = self.rule_amount.to_alipay_dict()
            else:
                params['rule_amount'] = self.rule_amount
        if self.rule_discount:
            if hasattr(self.rule_discount, 'to_alipay_dict'):
                params['rule_discount'] = self.rule_discount.to_alipay_dict()
            else:
                params['rule_discount'] = self.rule_discount
        if self.rule_period:
            if hasattr(self.rule_period, 'to_alipay_dict'):
                params['rule_period'] = self.rule_period.to_alipay_dict()
            else:
                params['rule_period'] = self.rule_period
        if self.rule_period_unit:
            if hasattr(self.rule_period_unit, 'to_alipay_dict'):
                params['rule_period_unit'] = self.rule_period_unit.to_alipay_dict()
            else:
                params['rule_period_unit'] = self.rule_period_unit
        if self.rule_times:
            if hasattr(self.rule_times, 'to_alipay_dict'):
                params['rule_times'] = self.rule_times.to_alipay_dict()
            else:
                params['rule_times'] = self.rule_times
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ActivityRuleDetail()
        if 'rule_amount' in d:
            o.rule_amount = d['rule_amount']
        if 'rule_discount' in d:
            o.rule_discount = d['rule_discount']
        if 'rule_period' in d:
            o.rule_period = d['rule_period']
        if 'rule_period_unit' in d:
            o.rule_period_unit = d['rule_period_unit']
        if 'rule_times' in d:
            o.rule_times = d['rule_times']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PromotionInfo(object):

    def __init__(self):
        self._brand_name = None
        self._collected = None
        self._collected_count = None
        self._detail_url = None
        self._icon_url = None
        self._main_image_url = None
        self._out_prize_id = None
        self._promotion_id = None
        self._title = None
        self._using_condition = None
        self._using_scope = None
        self._valid_date_from = None
        self._valid_date_to = None
        self._valid_time_text = None
        self._voucher_usage_status = None

    @property
    def brand_name(self):
        return self._brand_name

    @brand_name.setter
    def brand_name(self, value):
        self._brand_name = value
    @property
    def collected(self):
        return self._collected

    @collected.setter
    def collected(self, value):
        self._collected = value
    @property
    def collected_count(self):
        return self._collected_count

    @collected_count.setter
    def collected_count(self, value):
        self._collected_count = value
    @property
    def detail_url(self):
        return self._detail_url

    @detail_url.setter
    def detail_url(self, value):
        self._detail_url = value
    @property
    def icon_url(self):
        return self._icon_url

    @icon_url.setter
    def icon_url(self, value):
        self._icon_url = value
    @property
    def main_image_url(self):
        return self._main_image_url

    @main_image_url.setter
    def main_image_url(self, value):
        self._main_image_url = value
    @property
    def out_prize_id(self):
        return self._out_prize_id

    @out_prize_id.setter
    def out_prize_id(self, value):
        self._out_prize_id = value
    @property
    def promotion_id(self):
        return self._promotion_id

    @promotion_id.setter
    def promotion_id(self, value):
        self._promotion_id = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value
    @property
    def using_condition(self):
        return self._using_condition

    @using_condition.setter
    def using_condition(self, value):
        self._using_condition = value
    @property
    def using_scope(self):
        return self._using_scope

    @using_scope.setter
    def using_scope(self, value):
        self._using_scope = value
    @property
    def valid_date_from(self):
        return self._valid_date_from

    @valid_date_from.setter
    def valid_date_from(self, value):
        self._valid_date_from = value
    @property
    def valid_date_to(self):
        return self._valid_date_to

    @valid_date_to.setter
    def valid_date_to(self, value):
        self._valid_date_to = value
    @property
    def valid_time_text(self):
        return self._valid_time_text

    @valid_time_text.setter
    def valid_time_text(self, value):
        self._valid_time_text = value
    @property
    def voucher_usage_status(self):
        return self._voucher_usage_status

    @voucher_usage_status.setter
    def voucher_usage_status(self, value):
        self._voucher_usage_status = value


    def to_alipay_dict(self):
        params = dict()
        if self.brand_name:
            if hasattr(self.brand_name, 'to_alipay_dict'):
                params['brand_name'] = self.brand_name.to_alipay_dict()
            else:
                params['brand_name'] = self.brand_name
        if self.collected:
            if hasattr(self.collected, 'to_alipay_dict'):
                params['collected'] = self.collected.to_alipay_dict()
            else:
                params['collected'] = self.collected
        if self.collected_count:
            if hasattr(self.collected_count, 'to_alipay_dict'):
                params['collected_count'] = self.collected_count.to_alipay_dict()
            else:
                params['collected_count'] = self.collected_count
        if self.detail_url:
            if hasattr(self.detail_url, 'to_alipay_dict'):
                params['detail_url'] = self.detail_url.to_alipay_dict()
            else:
                params['detail_url'] = self.detail_url
        if self.icon_url:
            if hasattr(self.icon_url, 'to_alipay_dict'):
                params['icon_url'] = self.icon_url.to_alipay_dict()
            else:
                params['icon_url'] = self.icon_url
        if self.main_image_url:
            if hasattr(self.main_image_url, 'to_alipay_dict'):
                params['main_image_url'] = self.main_image_url.to_alipay_dict()
            else:
                params['main_image_url'] = self.main_image_url
        if self.out_prize_id:
            if hasattr(self.out_prize_id, 'to_alipay_dict'):
                params['out_prize_id'] = self.out_prize_id.to_alipay_dict()
            else:
                params['out_prize_id'] = self.out_prize_id
        if self.promotion_id:
            if hasattr(self.promotion_id, 'to_alipay_dict'):
                params['promotion_id'] = self.promotion_id.to_alipay_dict()
            else:
                params['promotion_id'] = self.promotion_id
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        if self.using_condition:
            if hasattr(self.using_condition, 'to_alipay_dict'):
                params['using_condition'] = self.using_condition.to_alipay_dict()
            else:
                params['using_condition'] = self.using_condition
        if self.using_scope:
            if hasattr(self.using_scope, 'to_alipay_dict'):
                params['using_scope'] = self.using_scope.to_alipay_dict()
            else:
                params['using_scope'] = self.using_scope
        if self.valid_date_from:
            if hasattr(self.valid_date_from, 'to_alipay_dict'):
                params['valid_date_from'] = self.valid_date_from.to_alipay_dict()
            else:
                params['valid_date_from'] = self.valid_date_from
        if self.valid_date_to:
            if hasattr(self.valid_date_to, 'to_alipay_dict'):
                params['valid_date_to'] = self.valid_date_to.to_alipay_dict()
            else:
                params['valid_date_to'] = self.valid_date_to
        if self.valid_time_text:
            if hasattr(self.valid_time_text, 'to_alipay_dict'):
                params['valid_time_text'] = self.valid_time_text.to_alipay_dict()
            else:
                params['valid_time_text'] = self.valid_time_text
        if self.voucher_usage_status:
            if hasattr(self.voucher_usage_status, 'to_alipay_dict'):
                params['voucher_usage_status'] = self.voucher_usage_status.to_alipay_dict()
            else:
                params['voucher_usage_status'] = self.voucher_usage_status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PromotionInfo()
        if 'brand_name' in d:
            o.brand_name = d['brand_name']
        if 'collected' in d:
            o.collected = d['collected']
        if 'collected_count' in d:
            o.collected_count = d['collected_count']
        if 'detail_url' in d:
            o.detail_url = d['detail_url']
        if 'icon_url' in d:
            o.icon_url = d['icon_url']
        if 'main_image_url' in d:
            o.main_image_url = d['main_image_url']
        if 'out_prize_id' in d:
            o.out_prize_id = d['out_prize_id']
        if 'promotion_id' in d:
            o.promotion_id = d['promotion_id']
        if 'title' in d:
            o.title = d['title']
        if 'using_condition' in d:
            o.using_condition = d['using_condition']
        if 'using_scope' in d:
            o.using_scope = d['using_scope']
        if 'valid_date_from' in d:
            o.valid_date_from = d['valid_date_from']
        if 'valid_date_to' in d:
            o.valid_date_to = d['valid_date_to']
        if 'valid_time_text' in d:
            o.valid_time_text = d['valid_time_text']
        if 'voucher_usage_status' in d:
            o.voucher_usage_status = d['voucher_usage_status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ComplexLabelRule(object):

    def __init__(self):
        self._label_id = None
        self._label_value = None
        self._operator = None

    @property
    def label_id(self):
        return self._label_id

    @label_id.setter
    def label_id(self, value):
        self._label_id = value
    @property
    def label_value(self):
        return self._label_value

    @label_value.setter
    def label_value(self, value):
        self._label_value = value
    @property
    def operator(self):
        return self._operator

    @operator.setter
    def operator(self, value):
        self._operator = value


    def to_alipay_dict(self):
        params = dict()
        if self.label_id:
            if hasattr(self.label_id, 'to_alipay_dict'):
                params['label_id'] = self.label_id.to_alipay_dict()
            else:
                params['label_id'] = self.label_id
        if self.label_value:
            if hasattr(self.label_value, 'to_alipay_dict'):
                params['label_value'] = self.label_value.to_alipay_dict()
            else:
                params['label_value'] = self.label_value
        if self.operator:
            if hasattr(self.operator, 'to_alipay_dict'):
                params['operator'] = self.operator.to_alipay_dict()
            else:
                params['operator'] = self.operator
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ComplexLabelRule()
        if 'label_id' in d:
            o.label_id = d['label_id']
        if 'label_value' in d:
            o.label_value = d['label_value']
        if 'operator' in d:
            o.operator = d['operator']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOverseasTravelGkaCampaignApplyModel(object):

    def __init__(self):
        self._camp_id = None
        self._client_ip = None
        self._device_info = None
        self._extend_info = None
        self._json_ua = None
        self._login_mobile = None
        self._user_id = None

    @property
    def camp_id(self):
        return self._camp_id

    @camp_id.setter
    def camp_id(self, value):
        self._camp_id = value
    @property
    def client_ip(self):
        return self._client_ip

    @client_ip.setter
    def client_ip(self, value):
        self._client_ip = value
    @property
    def device_info(self):
        return self._device_info

    @device_info.setter
    def device_info(self, value):
        self._device_info = value
    @property
    def extend_info(self):
        return self._extend_info

    @extend_info.setter
    def extend_info(self, value):
        self._extend_info = value
    @property
    def json_ua(self):
        return self._json_ua

    @json_ua.setter
    def json_ua(self, value):
        self._json_ua = value
    @property
    def login_mobile(self):
        return self._login_mobile

    @login_mobile.setter
    def login_mobile(self, value):
        self._login_mobile = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.camp_id:
            if hasattr(self.camp_id, 'to_alipay_dict'):
                params['camp_id'] = self.camp_id.to_alipay_dict()
            else:
                params['camp_id'] = self.camp_id
        if self.client_ip:
            if hasattr(self.client_ip, 'to_alipay_dict'):
                params['client_ip'] = self.client_ip.to_alipay_dict()
            else:
                params['client_ip'] = self.client_ip
        if self.device_info:
            if hasattr(self.device_info, 'to_alipay_dict'):
                params['device_info'] = self.device_info.to_alipay_dict()
            else:
                params['device_info'] = self.device_info
        if self.extend_info:
            if hasattr(self.extend_info, 'to_alipay_dict'):
                params['extend_info'] = self.extend_info.to_alipay_dict()
            else:
                params['extend_info'] = self.extend_info
        if self.json_ua:
            if hasattr(self.json_ua, 'to_alipay_dict'):
                params['json_ua'] = self.json_ua.to_alipay_dict()
            else:
                params['json_ua'] = self.json_ua
        if self.login_mobile:
            if hasattr(self.login_mobile, 'to_alipay_dict'):
                params['login_mobile'] = self.login_mobile.to_alipay_dict()
            else:
                params['login_mobile'] = self.login_mobile
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOverseasTravelGkaCampaignApplyModel()
        if 'camp_id' in d:
            o.camp_id = d['camp_id']
        if 'client_ip' in d:
            o.client_ip = d['client_ip']
        if 'device_info' in d:
            o.device_info = d['device_info']
        if 'extend_info' in d:
            o.extend_info = d['extend_info']
        if 'json_ua' in d:
            o.json_ua = d['json_ua']
        if 'login_mobile' in d:
            o.login_mobile = d['login_mobile']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayPcreditHuabeiPcreditmerchantProductorderCancelModel(object):

    def __init__(self):
        self._biz_from = None
        self._cancel_system_code = None
        self._cancel_type = None
        self._extending_info = None
        self._from_app = None
        self._memo = None
        self._order_id = None
        self._pid = None

    @property
    def biz_from(self):
        return self._biz_from

    @biz_from.setter
    def biz_from(self, value):
        self._biz_from = value
    @property
    def cancel_system_code(self):
        return self._cancel_system_code

    @cancel_system_code.setter
    def cancel_system_code(self, value):
        self._cancel_system_code = value
    @property
    def cancel_type(self):
        return self._cancel_type

    @cancel_type.setter
    def cancel_type(self, value):
        self._cancel_type = value
    @property
    def extending_info(self):
        return self._extending_info

    @extending_info.setter
    def extending_info(self, value):
        self._extending_info = value
    @property
    def from_app(self):
        return self._from_app

    @from_app.setter
    def from_app(self, value):
        self._from_app = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def pid(self):
        return self._pid

    @pid.setter
    def pid(self, value):
        self._pid = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_from:
            if hasattr(self.biz_from, 'to_alipay_dict'):
                params['biz_from'] = self.biz_from.to_alipay_dict()
            else:
                params['biz_from'] = self.biz_from
        if self.cancel_system_code:
            if hasattr(self.cancel_system_code, 'to_alipay_dict'):
                params['cancel_system_code'] = self.cancel_system_code.to_alipay_dict()
            else:
                params['cancel_system_code'] = self.cancel_system_code
        if self.cancel_type:
            if hasattr(self.cancel_type, 'to_alipay_dict'):
                params['cancel_type'] = self.cancel_type.to_alipay_dict()
            else:
                params['cancel_type'] = self.cancel_type
        if self.extending_info:
            if hasattr(self.extending_info, 'to_alipay_dict'):
                params['extending_info'] = self.extending_info.to_alipay_dict()
            else:
                params['extending_info'] = self.extending_info
        if self.from_app:
            if hasattr(self.from_app, 'to_alipay_dict'):
                params['from_app'] = self.from_app.to_alipay_dict()
            else:
                params['from_app'] = self.from_app
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.pid:
            if hasattr(self.pid, 'to_alipay_dict'):
                params['pid'] = self.pid.to_alipay_dict()
            else:
                params['pid'] = self.pid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayPcreditHuabeiPcreditmerchantProductorderCancelModel()
        if 'biz_from' in d:
            o.biz_from = d['biz_from']
        if 'cancel_system_code' in d:
            o.cancel_system_code = d['cancel_system_code']
        if 'cancel_type' in d:
            o.cancel_type = d['cancel_type']
        if 'extending_info' in d:
            o.extending_info = d['extending_info']
        if 'from_app' in d:
            o.from_app = d['from_app']
        if 'memo' in d:
            o.memo = d['memo']
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'pid' in d:
            o.pid = d['pid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PointAccountLog(object):

    def __init__(self):
        self._account_log_id = None
        self._balance = None
        self._order_no = None
        self._out_biz_no = None
        self._point_amount = None
        self._sub_trans_code = None
        self._sub_trans_code_cn = None
        self._trans_code = None
        self._trans_date = None
        self._trans_memo = None

    @property
    def account_log_id(self):
        return self._account_log_id

    @account_log_id.setter
    def account_log_id(self, value):
        self._account_log_id = value
    @property
    def balance(self):
        return self._balance

    @balance.setter
    def balance(self, value):
        self._balance = value
    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def point_amount(self):
        return self._point_amount

    @point_amount.setter
    def point_amount(self, value):
        self._point_amount = value
    @property
    def sub_trans_code(self):
        return self._sub_trans_code

    @sub_trans_code.setter
    def sub_trans_code(self, value):
        self._sub_trans_code = value
    @property
    def sub_trans_code_cn(self):
        return self._sub_trans_code_cn

    @sub_trans_code_cn.setter
    def sub_trans_code_cn(self, value):
        self._sub_trans_code_cn = value
    @property
    def trans_code(self):
        return self._trans_code

    @trans_code.setter
    def trans_code(self, value):
        self._trans_code = value
    @property
    def trans_date(self):
        return self._trans_date

    @trans_date.setter
    def trans_date(self, value):
        self._trans_date = value
    @property
    def trans_memo(self):
        return self._trans_memo

    @trans_memo.setter
    def trans_memo(self, value):
        self._trans_memo = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_log_id:
            if hasattr(self.account_log_id, 'to_alipay_dict'):
                params['account_log_id'] = self.account_log_id.to_alipay_dict()
            else:
                params['account_log_id'] = self.account_log_id
        if self.balance:
            if hasattr(self.balance, 'to_alipay_dict'):
                params['balance'] = self.balance.to_alipay_dict()
            else:
                params['balance'] = self.balance
        if self.order_no:
            if hasattr(self.order_no, 'to_alipay_dict'):
                params['order_no'] = self.order_no.to_alipay_dict()
            else:
                params['order_no'] = self.order_no
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.point_amount:
            if hasattr(self.point_amount, 'to_alipay_dict'):
                params['point_amount'] = self.point_amount.to_alipay_dict()
            else:
                params['point_amount'] = self.point_amount
        if self.sub_trans_code:
            if hasattr(self.sub_trans_code, 'to_alipay_dict'):
                params['sub_trans_code'] = self.sub_trans_code.to_alipay_dict()
            else:
                params['sub_trans_code'] = self.sub_trans_code
        if self.sub_trans_code_cn:
            if hasattr(self.sub_trans_code_cn, 'to_alipay_dict'):
                params['sub_trans_code_cn'] = self.sub_trans_code_cn.to_alipay_dict()
            else:
                params['sub_trans_code_cn'] = self.sub_trans_code_cn
        if self.trans_code:
            if hasattr(self.trans_code, 'to_alipay_dict'):
                params['trans_code'] = self.trans_code.to_alipay_dict()
            else:
                params['trans_code'] = self.trans_code
        if self.trans_date:
            if hasattr(self.trans_date, 'to_alipay_dict'):
                params['trans_date'] = self.trans_date.to_alipay_dict()
            else:
                params['trans_date'] = self.trans_date
        if self.trans_memo:
            if hasattr(self.trans_memo, 'to_alipay_dict'):
                params['trans_memo'] = self.trans_memo.to_alipay_dict()
            else:
                params['trans_memo'] = self.trans_memo
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PointAccountLog()
        if 'account_log_id' in d:
            o.account_log_id = d['account_log_id']
        if 'balance' in d:
            o.balance = d['balance']
        if 'order_no' in d:
            o.order_no = d['order_no']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'point_amount' in d:
            o.point_amount = d['point_amount']
        if 'sub_trans_code' in d:
            o.sub_trans_code = d['sub_trans_code']
        if 'sub_trans_code_cn' in d:
            o.sub_trans_code_cn = d['sub_trans_code_cn']
        if 'trans_code' in d:
            o.trans_code = d['trans_code']
        if 'trans_date' in d:
            o.trans_date = d['trans_date']
        if 'trans_memo' in d:
            o.trans_memo = d['trans_memo']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.InvoicePDFSynModel import InvoicePDFSynModel


class AlipayEbppInvoiceSyncSimpleSendModel(object):

    def __init__(self):
        self._invoice_info = None
        self._m_short_name = None
        self._sub_m_short_name = None

    @property
    def invoice_info(self):
        return self._invoice_info

    @invoice_info.setter
    def invoice_info(self, value):
        if isinstance(value, InvoicePDFSynModel):
            self._invoice_info = value
        else:
            self._invoice_info = InvoicePDFSynModel.from_alipay_dict(value)
    @property
    def m_short_name(self):
        return self._m_short_name

    @m_short_name.setter
    def m_short_name(self, value):
        self._m_short_name = value
    @property
    def sub_m_short_name(self):
        return self._sub_m_short_name

    @sub_m_short_name.setter
    def sub_m_short_name(self, value):
        self._sub_m_short_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.invoice_info:
            if hasattr(self.invoice_info, 'to_alipay_dict'):
                params['invoice_info'] = self.invoice_info.to_alipay_dict()
            else:
                params['invoice_info'] = self.invoice_info
        if self.m_short_name:
            if hasattr(self.m_short_name, 'to_alipay_dict'):
                params['m_short_name'] = self.m_short_name.to_alipay_dict()
            else:
                params['m_short_name'] = self.m_short_name
        if self.sub_m_short_name:
            if hasattr(self.sub_m_short_name, 'to_alipay_dict'):
                params['sub_m_short_name'] = self.sub_m_short_name.to_alipay_dict()
            else:
                params['sub_m_short_name'] = self.sub_m_short_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppInvoiceSyncSimpleSendModel()
        if 'invoice_info' in d:
            o.invoice_info = d['invoice_info']
        if 'm_short_name' in d:
            o.m_short_name = d['m_short_name']
        if 'sub_m_short_name' in d:
            o.sub_m_short_name = d['sub_m_short_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFundCouponOrderAgreementPayModel(object):

    def __init__(self):
        self._amount = None
        self._extra_param = None
        self._order_title = None
        self._out_order_no = None
        self._out_request_no = None
        self._pay_timeout = None
        self._payer_user_id = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def extra_param(self):
        return self._extra_param

    @extra_param.setter
    def extra_param(self, value):
        self._extra_param = value
    @property
    def order_title(self):
        return self._order_title

    @order_title.setter
    def order_title(self, value):
        self._order_title = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def pay_timeout(self):
        return self._pay_timeout

    @pay_timeout.setter
    def pay_timeout(self, value):
        self._pay_timeout = value
    @property
    def payer_user_id(self):
        return self._payer_user_id

    @payer_user_id.setter
    def payer_user_id(self, value):
        self._payer_user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.extra_param:
            if hasattr(self.extra_param, 'to_alipay_dict'):
                params['extra_param'] = self.extra_param.to_alipay_dict()
            else:
                params['extra_param'] = self.extra_param
        if self.order_title:
            if hasattr(self.order_title, 'to_alipay_dict'):
                params['order_title'] = self.order_title.to_alipay_dict()
            else:
                params['order_title'] = self.order_title
        if self.out_order_no:
            if hasattr(self.out_order_no, 'to_alipay_dict'):
                params['out_order_no'] = self.out_order_no.to_alipay_dict()
            else:
                params['out_order_no'] = self.out_order_no
        if self.out_request_no:
            if hasattr(self.out_request_no, 'to_alipay_dict'):
                params['out_request_no'] = self.out_request_no.to_alipay_dict()
            else:
                params['out_request_no'] = self.out_request_no
        if self.pay_timeout:
            if hasattr(self.pay_timeout, 'to_alipay_dict'):
                params['pay_timeout'] = self.pay_timeout.to_alipay_dict()
            else:
                params['pay_timeout'] = self.pay_timeout
        if self.payer_user_id:
            if hasattr(self.payer_user_id, 'to_alipay_dict'):
                params['payer_user_id'] = self.payer_user_id.to_alipay_dict()
            else:
                params['payer_user_id'] = self.payer_user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundCouponOrderAgreementPayModel()
        if 'amount' in d:
            o.amount = d['amount']
        if 'extra_param' in d:
            o.extra_param = d['extra_param']
        if 'order_title' in d:
            o.order_title = d['order_title']
        if 'out_order_no' in d:
            o.out_order_no = d['out_order_no']
        if 'out_request_no' in d:
            o.out_request_no = d['out_request_no']
        if 'pay_timeout' in d:
            o.pay_timeout = d['pay_timeout']
        if 'payer_user_id' in d:
            o.payer_user_id = d['payer_user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserElectronicidUserbarcodeCreateModel(object):

    def __init__(self):
        self._cert_id = None
        self._expire_time = None

    @property
    def cert_id(self):
        return self._cert_id

    @cert_id.setter
    def cert_id(self, value):
        self._cert_id = value
    @property
    def expire_time(self):
        return self._expire_time

    @expire_time.setter
    def expire_time(self, value):
        self._expire_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.cert_id:
            if hasattr(self.cert_id, 'to_alipay_dict'):
                params['cert_id'] = self.cert_id.to_alipay_dict()
            else:
                params['cert_id'] = self.cert_id
        if self.expire_time:
            if hasattr(self.expire_time, 'to_alipay_dict'):
                params['expire_time'] = self.expire_time.to_alipay_dict()
            else:
                params['expire_time'] = self.expire_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserElectronicidUserbarcodeCreateModel()
        if 'cert_id' in d:
            o.cert_id = d['cert_id']
        if 'expire_time' in d:
            o.expire_time = d['expire_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.VoucherSendGuide import VoucherSendGuide
from alipay.aop.api.domain.VoucherUseGuide import VoucherUseGuide


class CustomerGuide(object):

    def __init__(self):
        self._mini_app_id = None
        self._mini_app_path = None
        self._real_shop_ids = None
        self._service_codes = None
        self._shop_ids = None
        self._store_ids = None
        self._voucher_send_guide = None
        self._voucher_use_guide = None

    @property
    def mini_app_id(self):
        return self._mini_app_id

    @mini_app_id.setter
    def mini_app_id(self, value):
        self._mini_app_id = value
    @property
    def mini_app_path(self):
        return self._mini_app_path

    @mini_app_path.setter
    def mini_app_path(self, value):
        self._mini_app_path = value
    @property
    def real_shop_ids(self):
        return self._real_shop_ids

    @real_shop_ids.setter
    def real_shop_ids(self, value):
        if isinstance(value, list):
            self._real_shop_ids = list()
            for i in value:
                self._real_shop_ids.append(i)
    @property
    def service_codes(self):
        return self._service_codes

    @service_codes.setter
    def service_codes(self, value):
        if isinstance(value, list):
            self._service_codes = list()
            for i in value:
                self._service_codes.append(i)
    @property
    def shop_ids(self):
        return self._shop_ids

    @shop_ids.setter
    def shop_ids(self, value):
        if isinstance(value, list):
            self._shop_ids = list()
            for i in value:
                self._shop_ids.append(i)
    @property
    def store_ids(self):
        return self._store_ids

    @store_ids.setter
    def store_ids(self, value):
        if isinstance(value, list):
            self._store_ids = list()
            for i in value:
                self._store_ids.append(i)
    @property
    def voucher_send_guide(self):
        return self._voucher_send_guide

    @voucher_send_guide.setter
    def voucher_send_guide(self, value):
        if isinstance(value, VoucherSendGuide):
            self._voucher_send_guide = value
        else:
            self._voucher_send_guide = VoucherSendGuide.from_alipay_dict(value)
    @property
    def voucher_use_guide(self):
        return self._voucher_use_guide

    @voucher_use_guide.setter
    def voucher_use_guide(self, value):
        if isinstance(value, VoucherUseGuide):
            self._voucher_use_guide = value
        else:
            self._voucher_use_guide = VoucherUseGuide.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.mini_app_id:
            if hasattr(self.mini_app_id, 'to_alipay_dict'):
                params['mini_app_id'] = self.mini_app_id.to_alipay_dict()
            else:
                params['mini_app_id'] = self.mini_app_id
        if self.mini_app_path:
            if hasattr(self.mini_app_path, 'to_alipay_dict'):
                params['mini_app_path'] = self.mini_app_path.to_alipay_dict()
            else:
                params['mini_app_path'] = self.mini_app_path
        if self.real_shop_ids:
            if isinstance(self.real_shop_ids, list):
                for i in range(0, len(self.real_shop_ids)):
                    element = self.real_shop_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.real_shop_ids[i] = element.to_alipay_dict()
            if hasattr(self.real_shop_ids, 'to_alipay_dict'):
                params['real_shop_ids'] = self.real_shop_ids.to_alipay_dict()
            else:
                params['real_shop_ids'] = self.real_shop_ids
        if self.service_codes:
            if isinstance(self.service_codes, list):
                for i in range(0, len(self.service_codes)):
                    element = self.service_codes[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.service_codes[i] = element.to_alipay_dict()
            if hasattr(self.service_codes, 'to_alipay_dict'):
                params['service_codes'] = self.service_codes.to_alipay_dict()
            else:
                params['service_codes'] = self.service_codes
        if self.shop_ids:
            if isinstance(self.shop_ids, list):
                for i in range(0, len(self.shop_ids)):
                    element = self.shop_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.shop_ids[i] = element.to_alipay_dict()
            if hasattr(self.shop_ids, 'to_alipay_dict'):
                params['shop_ids'] = self.shop_ids.to_alipay_dict()
            else:
                params['shop_ids'] = self.shop_ids
        if self.store_ids:
            if isinstance(self.store_ids, list):
                for i in range(0, len(self.store_ids)):
                    element = self.store_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.store_ids[i] = element.to_alipay_dict()
            if hasattr(self.store_ids, 'to_alipay_dict'):
                params['store_ids'] = self.store_ids.to_alipay_dict()
            else:
                params['store_ids'] = self.store_ids
        if self.voucher_send_guide:
            if hasattr(self.voucher_send_guide, 'to_alipay_dict'):
                params['voucher_send_guide'] = self.voucher_send_guide.to_alipay_dict()
            else:
                params['voucher_send_guide'] = self.voucher_send_guide
        if self.voucher_use_guide:
            if hasattr(self.voucher_use_guide, 'to_alipay_dict'):
                params['voucher_use_guide'] = self.voucher_use_guide.to_alipay_dict()
            else:
                params['voucher_use_guide'] = self.voucher_use_guide
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CustomerGuide()
        if 'mini_app_id' in d:
            o.mini_app_id = d['mini_app_id']
        if 'mini_app_path' in d:
            o.mini_app_path = d['mini_app_path']
        if 'real_shop_ids' in d:
            o.real_shop_ids = d['real_shop_ids']
        if 'service_codes' in d:
            o.service_codes = d['service_codes']
        if 'shop_ids' in d:
            o.shop_ids = d['shop_ids']
        if 'store_ids' in d:
            o.store_ids = d['store_ids']
        if 'voucher_send_guide' in d:
            o.voucher_send_guide = d['voucher_send_guide']
        if 'voucher_use_guide' in d:
            o.voucher_use_guide = d['voucher_use_guide']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenAppXwbtstabcQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenAppXwbtstabcQueryResponse, self).__init__()
        self._xwbbbdd = None

    @property
    def xwbbbdd(self):
        return self._xwbbbdd

    @xwbbbdd.setter
    def xwbbbdd(self, value):
        self._xwbbbdd = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenAppXwbtstabcQueryResponse, self).parse_response_content(response_content)
        if 'xwbbbdd' in response:
            self.xwbbbdd = response['xwbbbdd']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OpenApiPeopleDTO(object):

    def __init__(self):
        self._nick_name = None
        self._real_name = None
        self._role = None
        self._work_no = None

    @property
    def nick_name(self):
        return self._nick_name

    @nick_name.setter
    def nick_name(self, value):
        self._nick_name = value
    @property
    def real_name(self):
        return self._real_name

    @real_name.setter
    def real_name(self, value):
        self._real_name = value
    @property
    def role(self):
        return self._role

    @role.setter
    def role(self, value):
        self._role = value
    @property
    def work_no(self):
        return self._work_no

    @work_no.setter
    def work_no(self, value):
        self._work_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.nick_name:
            if hasattr(self.nick_name, 'to_alipay_dict'):
                params['nick_name'] = self.nick_name.to_alipay_dict()
            else:
                params['nick_name'] = self.nick_name
        if self.real_name:
            if hasattr(self.real_name, 'to_alipay_dict'):
                params['real_name'] = self.real_name.to_alipay_dict()
            else:
                params['real_name'] = self.real_name
        if self.role:
            if hasattr(self.role, 'to_alipay_dict'):
                params['role'] = self.role.to_alipay_dict()
            else:
                params['role'] = self.role
        if self.work_no:
            if hasattr(self.work_no, 'to_alipay_dict'):
                params['work_no'] = self.work_no.to_alipay_dict()
            else:
                params['work_no'] = self.work_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OpenApiPeopleDTO()
        if 'nick_name' in d:
            o.nick_name = d['nick_name']
        if 'real_name' in d:
            o.real_name = d['real_name']
        if 'role' in d:
            o.role = d['role']
        if 'work_no' in d:
            o.work_no = d['work_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.MemberCardUserTransactionDetail import MemberCardUserTransactionDetail


class AntMerchantExpandMembercardTransactionBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AntMerchantExpandMembercardTransactionBatchqueryResponse, self).__init__()
        self._partner_id = None
        self._transaction_detail_list = None

    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def transaction_detail_list(self):
        return self._transaction_detail_list

    @transaction_detail_list.setter
    def transaction_detail_list(self, value):
        if isinstance(value, list):
            self._transaction_detail_list = list()
            for i in value:
                if isinstance(i, MemberCardUserTransactionDetail):
                    self._transaction_detail_list.append(i)
                else:
                    self._transaction_detail_list.append(MemberCardUserTransactionDetail.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AntMerchantExpandMembercardTransactionBatchqueryResponse, self).parse_response_content(response_content)
        if 'partner_id' in response:
            self.partner_id = response['partner_id']
        if 'transaction_detail_list' in response:
            self.transaction_detail_list = response['transaction_detail_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ReportCondition import ReportCondition


class AlisisReport(object):

    def __init__(self):
        self._conditions = None
        self._report_desc = None
        self._report_name = None
        self._report_uk = None

    @property
    def conditions(self):
        return self._conditions

    @conditions.setter
    def conditions(self, value):
        if isinstance(value, list):
            self._conditions = list()
            for i in value:
                if isinstance(i, ReportCondition):
                    self._conditions.append(i)
                else:
                    self._conditions.append(ReportCondition.from_alipay_dict(i))
    @property
    def report_desc(self):
        return self._report_desc

    @report_desc.setter
    def report_desc(self, value):
        self._report_desc = value
    @property
    def report_name(self):
        return self._report_name

    @report_name.setter
    def report_name(self, value):
        self._report_name = value
    @property
    def report_uk(self):
        return self._report_uk

    @report_uk.setter
    def report_uk(self, value):
        self._report_uk = value


    def to_alipay_dict(self):
        params = dict()
        if self.conditions:
            if isinstance(self.conditions, list):
                for i in range(0, len(self.conditions)):
                    element = self.conditions[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.conditions[i] = element.to_alipay_dict()
            if hasattr(self.conditions, 'to_alipay_dict'):
                params['conditions'] = self.conditions.to_alipay_dict()
            else:
                params['conditions'] = self.conditions
        if self.report_desc:
            if hasattr(self.report_desc, 'to_alipay_dict'):
                params['report_desc'] = self.report_desc.to_alipay_dict()
            else:
                params['report_desc'] = self.report_desc
        if self.report_name:
            if hasattr(self.report_name, 'to_alipay_dict'):
                params['report_name'] = self.report_name.to_alipay_dict()
            else:
                params['report_name'] = self.report_name
        if self.report_uk:
            if hasattr(self.report_uk, 'to_alipay_dict'):
                params['report_uk'] = self.report_uk.to_alipay_dict()
            else:
                params['report_uk'] = self.report_uk
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlisisReport()
        if 'conditions' in d:
            o.conditions = d['conditions']
        if 'report_desc' in d:
            o.report_desc = d['report_desc']
        if 'report_name' in d:
            o.report_name = d['report_name']
        if 'report_uk' in d:
            o.report_uk = d['report_uk']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayPcreditHuabeiMobileauthSignConsultModel(object):

    def __init__(self):
        self._request = None

    @property
    def request(self):
        return self._request

    @request.setter
    def request(self, value):
        self._request = value


    def to_alipay_dict(self):
        params = dict()
        if self.request:
            if hasattr(self.request, 'to_alipay_dict'):
                params['request'] = self.request.to_alipay_dict()
            else:
                params['request'] = self.request
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayPcreditHuabeiMobileauthSignConsultModel()
        if 'request' in d:
            o.request = d['request']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class FundTransferLogResult(object):

    def __init__(self):
        self._amount = None
        self._remark = None
        self._source_account = None
        self._target_account = None
        self._trans_create_time = None
        self._trans_date = None
        self._type = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value
    @property
    def source_account(self):
        return self._source_account

    @source_account.setter
    def source_account(self, value):
        self._source_account = value
    @property
    def target_account(self):
        return self._target_account

    @target_account.setter
    def target_account(self, value):
        self._target_account = value
    @property
    def trans_create_time(self):
        return self._trans_create_time

    @trans_create_time.setter
    def trans_create_time(self, value):
        self._trans_create_time = value
    @property
    def trans_date(self):
        return self._trans_date

    @trans_date.setter
    def trans_date(self, value):
        self._trans_date = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.remark:
            if hasattr(self.remark, 'to_alipay_dict'):
                params['remark'] = self.remark.to_alipay_dict()
            else:
                params['remark'] = self.remark
        if self.source_account:
            if hasattr(self.source_account, 'to_alipay_dict'):
                params['source_account'] = self.source_account.to_alipay_dict()
            else:
                params['source_account'] = self.source_account
        if self.target_account:
            if hasattr(self.target_account, 'to_alipay_dict'):
                params['target_account'] = self.target_account.to_alipay_dict()
            else:
                params['target_account'] = self.target_account
        if self.trans_create_time:
            if hasattr(self.trans_create_time, 'to_alipay_dict'):
                params['trans_create_time'] = self.trans_create_time.to_alipay_dict()
            else:
                params['trans_create_time'] = self.trans_create_time
        if self.trans_date:
            if hasattr(self.trans_date, 'to_alipay_dict'):
                params['trans_date'] = self.trans_date.to_alipay_dict()
            else:
                params['trans_date'] = self.trans_date
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = FundTransferLogResult()
        if 'amount' in d:
            o.amount = d['amount']
        if 'remark' in d:
            o.remark = d['remark']
        if 'source_account' in d:
            o.source_account = d['source_account']
        if 'target_account' in d:
            o.target_account = d['target_account']
        if 'trans_create_time' in d:
            o.trans_create_time = d['trans_create_time']
        if 'trans_date' in d:
            o.trans_date = d['trans_date']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OperatorAccountVO(object):

    def __init__(self):
        self._account_id = None
        self._account_type = None

    @property
    def account_id(self):
        return self._account_id

    @account_id.setter
    def account_id(self, value):
        self._account_id = value
    @property
    def account_type(self):
        return self._account_type

    @account_type.setter
    def account_type(self, value):
        self._account_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_id:
            if hasattr(self.account_id, 'to_alipay_dict'):
                params['account_id'] = self.account_id.to_alipay_dict()
            else:
                params['account_id'] = self.account_id
        if self.account_type:
            if hasattr(self.account_type, 'to_alipay_dict'):
                params['account_type'] = self.account_type.to_alipay_dict()
            else:
                params['account_type'] = self.account_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OperatorAccountVO()
        if 'account_id' in d:
            o.account_id = d['account_id']
        if 'account_type' in d:
            o.account_type = d['account_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MorphoCreateApp import MorphoCreateApp
from alipay.aop.api.domain.MorphoIdentity import MorphoIdentity
from alipay.aop.api.domain.MorphoCreateSource import MorphoCreateSource
from alipay.aop.api.domain.MorphoTemplate import MorphoTemplate


class AlipayOpenMiniMorphoAppCreateModel(object):

    def __init__(self):
        self._application = None
        self._identity = None
        self._source = None
        self._template = None

    @property
    def application(self):
        return self._application

    @application.setter
    def application(self, value):
        if isinstance(value, MorphoCreateApp):
            self._application = value
        else:
            self._application = MorphoCreateApp.from_alipay_dict(value)
    @property
    def identity(self):
        return self._identity

    @identity.setter
    def identity(self, value):
        if isinstance(value, MorphoIdentity):
            self._identity = value
        else:
            self._identity = MorphoIdentity.from_alipay_dict(value)
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        if isinstance(value, MorphoCreateSource):
            self._source = value
        else:
            self._source = MorphoCreateSource.from_alipay_dict(value)
    @property
    def template(self):
        return self._template

    @template.setter
    def template(self, value):
        if isinstance(value, MorphoTemplate):
            self._template = value
        else:
            self._template = MorphoTemplate.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.application:
            if hasattr(self.application, 'to_alipay_dict'):
                params['application'] = self.application.to_alipay_dict()
            else:
                params['application'] = self.application
        if self.identity:
            if hasattr(self.identity, 'to_alipay_dict'):
                params['identity'] = self.identity.to_alipay_dict()
            else:
                params['identity'] = self.identity
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        if self.template:
            if hasattr(self.template, 'to_alipay_dict'):
                params['template'] = self.template.to_alipay_dict()
            else:
                params['template'] = self.template
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniMorphoAppCreateModel()
        if 'application' in d:
            o.application = d['application']
        if 'identity' in d:
            o.identity = d['identity']
        if 'source' in d:
            o.source = d['source']
        if 'template' in d:
            o.template = d['template']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class ZhimaCreditPeZmgoPreorderCreateResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaCreditPeZmgoPreorderCreateResponse, self).__init__()
        self._biz_type = None
        self._partner_id = None
        self._preorder_no = None

    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def preorder_no(self):
        return self._preorder_no

    @preorder_no.setter
    def preorder_no(self, value):
        self._preorder_no = value

    def parse_response_content(self, response_content):
        response = super(ZhimaCreditPeZmgoPreorderCreateResponse, self).parse_response_content(response_content)
        if 'biz_type' in response:
            self.biz_type = response['biz_type']
        if 'partner_id' in response:
            self.partner_id = response['partner_id']
        if 'preorder_no' in response:
            self.preorder_no = response['preorder_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoMycarMaintainAftersaleSyncModel(object):

    def __init__(self):
        self._aftersale_no = None
        self._refuse_reason = None
        self._status = None

    @property
    def aftersale_no(self):
        return self._aftersale_no

    @aftersale_no.setter
    def aftersale_no(self, value):
        self._aftersale_no = value
    @property
    def refuse_reason(self):
        return self._refuse_reason

    @refuse_reason.setter
    def refuse_reason(self, value):
        self._refuse_reason = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.aftersale_no:
            if hasattr(self.aftersale_no, 'to_alipay_dict'):
                params['aftersale_no'] = self.aftersale_no.to_alipay_dict()
            else:
                params['aftersale_no'] = self.aftersale_no
        if self.refuse_reason:
            if hasattr(self.refuse_reason, 'to_alipay_dict'):
                params['refuse_reason'] = self.refuse_reason.to_alipay_dict()
            else:
                params['refuse_reason'] = self.refuse_reason
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoMycarMaintainAftersaleSyncModel()
        if 'aftersale_no' in d:
            o.aftersale_no = d['aftersale_no']
        if 'refuse_reason' in d:
            o.refuse_reason = d['refuse_reason']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.SnApplyInfo import SnApplyInfo


class AlipayCommerceIotSnApplyBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceIotSnApplyBatchqueryResponse, self).__init__()
        self._apply_list = None
        self._total = None

    @property
    def apply_list(self):
        return self._apply_list

    @apply_list.setter
    def apply_list(self, value):
        if isinstance(value, list):
            self._apply_list = list()
            for i in value:
                if isinstance(i, SnApplyInfo):
                    self._apply_list.append(i)
                else:
                    self._apply_list.append(SnApplyInfo.from_alipay_dict(i))
    @property
    def total(self):
        return self._total

    @total.setter
    def total(self, value):
        self._total = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceIotSnApplyBatchqueryResponse, self).parse_response_content(response_content)
        if 'apply_list' in response:
            self.apply_list = response['apply_list']
        if 'total' in response:
            self.total = response['total']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ProductVOOptions import ProductVOOptions


class AntProdpaasProductCommonQueryModel(object):

    def __init__(self):
        self._product_code = None
        self._product_options = None
        self._product_version = None

    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def product_options(self):
        return self._product_options

    @product_options.setter
    def product_options(self, value):
        if isinstance(value, ProductVOOptions):
            self._product_options = value
        else:
            self._product_options = ProductVOOptions.from_alipay_dict(value)
    @property
    def product_version(self):
        return self._product_version

    @product_version.setter
    def product_version(self, value):
        self._product_version = value


    def to_alipay_dict(self):
        params = dict()
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.product_options:
            if hasattr(self.product_options, 'to_alipay_dict'):
                params['product_options'] = self.product_options.to_alipay_dict()
            else:
                params['product_options'] = self.product_options
        if self.product_version:
            if hasattr(self.product_version, 'to_alipay_dict'):
                params['product_version'] = self.product_version.to_alipay_dict()
            else:
                params['product_version'] = self.product_version
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntProdpaasProductCommonQueryModel()
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'product_options' in d:
            o.product_options = d['product_options']
        if 'product_version' in d:
            o.product_version = d['product_version']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class NewsfeedMediaVideoInfo(object):

    def __init__(self):
        self._height = None
        self._img_id = None
        self._video_id = None
        self._width = None

    @property
    def height(self):
        return self._height

    @height.setter
    def height(self, value):
        self._height = value
    @property
    def img_id(self):
        return self._img_id

    @img_id.setter
    def img_id(self, value):
        self._img_id = value
    @property
    def video_id(self):
        return self._video_id

    @video_id.setter
    def video_id(self, value):
        self._video_id = value
    @property
    def width(self):
        return self._width

    @width.setter
    def width(self, value):
        self._width = value


    def to_alipay_dict(self):
        params = dict()
        if self.height:
            if hasattr(self.height, 'to_alipay_dict'):
                params['height'] = self.height.to_alipay_dict()
            else:
                params['height'] = self.height
        if self.img_id:
            if hasattr(self.img_id, 'to_alipay_dict'):
                params['img_id'] = self.img_id.to_alipay_dict()
            else:
                params['img_id'] = self.img_id
        if self.video_id:
            if hasattr(self.video_id, 'to_alipay_dict'):
                params['video_id'] = self.video_id.to_alipay_dict()
            else:
                params['video_id'] = self.video_id
        if self.width:
            if hasattr(self.width, 'to_alipay_dict'):
                params['width'] = self.width.to_alipay_dict()
            else:
                params['width'] = self.width
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = NewsfeedMediaVideoInfo()
        if 'height' in d:
            o.height = d['height']
        if 'img_id' in d:
            o.img_id = d['img_id']
        if 'video_id' in d:
            o.video_id = d['video_id']
        if 'width' in d:
            o.width = d['width']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ShopOrderConfigInfo import ShopOrderConfigInfo


class KoubeiCateringConfigModifyModel(object):

    def __init__(self):
        self._request_id = None
        self._shop_config_list = None

    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def shop_config_list(self):
        return self._shop_config_list

    @shop_config_list.setter
    def shop_config_list(self, value):
        if isinstance(value, list):
            self._shop_config_list = list()
            for i in value:
                if isinstance(i, ShopOrderConfigInfo):
                    self._shop_config_list.append(i)
                else:
                    self._shop_config_list.append(ShopOrderConfigInfo.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        if self.shop_config_list:
            if isinstance(self.shop_config_list, list):
                for i in range(0, len(self.shop_config_list)):
                    element = self.shop_config_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.shop_config_list[i] = element.to_alipay_dict()
            if hasattr(self.shop_config_list, 'to_alipay_dict'):
                params['shop_config_list'] = self.shop_config_list.to_alipay_dict()
            else:
                params['shop_config_list'] = self.shop_config_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringConfigModifyModel()
        if 'request_id' in d:
            o.request_id = d['request_id']
        if 'shop_config_list' in d:
            o.shop_config_list = d['shop_config_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InterTradeStartContractApprovalResult(object):

    def __init__(self):
        self._need_approval_flag = None

    @property
    def need_approval_flag(self):
        return self._need_approval_flag

    @need_approval_flag.setter
    def need_approval_flag(self, value):
        self._need_approval_flag = value


    def to_alipay_dict(self):
        params = dict()
        if self.need_approval_flag:
            if hasattr(self.need_approval_flag, 'to_alipay_dict'):
                params['need_approval_flag'] = self.need_approval_flag.to_alipay_dict()
            else:
                params['need_approval_flag'] = self.need_approval_flag
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InterTradeStartContractApprovalResult()
        if 'need_approval_flag' in d:
            o.need_approval_flag = d['need_approval_flag']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceEducateTuitioncodePlanDisburseModel(object):

    def __init__(self):
        self._out_order_no = None
        self._out_request_id = None
        self._plan_id = None
        self._plan_ids = None
        self._smid = None
        self._user_id = None

    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def out_request_id(self):
        return self._out_request_id

    @out_request_id.setter
    def out_request_id(self, value):
        self._out_request_id = value
    @property
    def plan_id(self):
        return self._plan_id

    @plan_id.setter
    def plan_id(self, value):
        self._plan_id = value
    @property
    def plan_ids(self):
        return self._plan_ids

    @plan_ids.setter
    def plan_ids(self, value):
        if isinstance(value, list):
            self._plan_ids = list()
            for i in value:
                self._plan_ids.append(i)
    @property
    def smid(self):
        return self._smid

    @smid.setter
    def smid(self, value):
        self._smid = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.out_order_no:
            if hasattr(self.out_order_no, 'to_alipay_dict'):
                params['out_order_no'] = self.out_order_no.to_alipay_dict()
            else:
                params['out_order_no'] = self.out_order_no
        if self.out_request_id:
            if hasattr(self.out_request_id, 'to_alipay_dict'):
                params['out_request_id'] = self.out_request_id.to_alipay_dict()
            else:
                params['out_request_id'] = self.out_request_id
        if self.plan_id:
            if hasattr(self.plan_id, 'to_alipay_dict'):
                params['plan_id'] = self.plan_id.to_alipay_dict()
            else:
                params['plan_id'] = self.plan_id
        if self.plan_ids:
            if isinstance(self.plan_ids, list):
                for i in range(0, len(self.plan_ids)):
                    element = self.plan_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.plan_ids[i] = element.to_alipay_dict()
            if hasattr(self.plan_ids, 'to_alipay_dict'):
                params['plan_ids'] = self.plan_ids.to_alipay_dict()
            else:
                params['plan_ids'] = self.plan_ids
        if self.smid:
            if hasattr(self.smid, 'to_alipay_dict'):
                params['smid'] = self.smid.to_alipay_dict()
            else:
                params['smid'] = self.smid
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceEducateTuitioncodePlanDisburseModel()
        if 'out_order_no' in d:
            o.out_order_no = d['out_order_no']
        if 'out_request_id' in d:
            o.out_request_id = d['out_request_id']
        if 'plan_id' in d:
            o.plan_id = d['plan_id']
        if 'plan_ids' in d:
            o.plan_ids = d['plan_ids']
        if 'smid' in d:
            o.smid = d['smid']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class YLBProfitDetailInfo(object):

    def __init__(self):
        self._day_profit = None
        self._month_profit = None
        self._total_profit = None
        self._week_profit = None

    @property
    def day_profit(self):
        return self._day_profit

    @day_profit.setter
    def day_profit(self, value):
        self._day_profit = value
    @property
    def month_profit(self):
        return self._month_profit

    @month_profit.setter
    def month_profit(self, value):
        self._month_profit = value
    @property
    def total_profit(self):
        return self._total_profit

    @total_profit.setter
    def total_profit(self, value):
        self._total_profit = value
    @property
    def week_profit(self):
        return self._week_profit

    @week_profit.setter
    def week_profit(self, value):
        self._week_profit = value


    def to_alipay_dict(self):
        params = dict()
        if self.day_profit:
            if hasattr(self.day_profit, 'to_alipay_dict'):
                params['day_profit'] = self.day_profit.to_alipay_dict()
            else:
                params['day_profit'] = self.day_profit
        if self.month_profit:
            if hasattr(self.month_profit, 'to_alipay_dict'):
                params['month_profit'] = self.month_profit.to_alipay_dict()
            else:
                params['month_profit'] = self.month_profit
        if self.total_profit:
            if hasattr(self.total_profit, 'to_alipay_dict'):
                params['total_profit'] = self.total_profit.to_alipay_dict()
            else:
                params['total_profit'] = self.total_profit
        if self.week_profit:
            if hasattr(self.week_profit, 'to_alipay_dict'):
                params['week_profit'] = self.week_profit.to_alipay_dict()
            else:
                params['week_profit'] = self.week_profit
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = YLBProfitDetailInfo()
        if 'day_profit' in d:
            o.day_profit = d['day_profit']
        if 'month_profit' in d:
            o.month_profit = d['month_profit']
        if 'total_profit' in d:
            o.total_profit = d['total_profit']
        if 'week_profit' in d:
            o.week_profit = d['week_profit']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceIotMdeviceprodBehaviorlogBatchqueryModel(object):

    def __init__(self):
        self._behavior_type = None
        self._device_sn = None
        self._imei = None
        self._item_id = None

    @property
    def behavior_type(self):
        return self._behavior_type

    @behavior_type.setter
    def behavior_type(self, value):
        self._behavior_type = value
    @property
    def device_sn(self):
        return self._device_sn

    @device_sn.setter
    def device_sn(self, value):
        self._device_sn = value
    @property
    def imei(self):
        return self._imei

    @imei.setter
    def imei(self, value):
        self._imei = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.behavior_type:
            if hasattr(self.behavior_type, 'to_alipay_dict'):
                params['behavior_type'] = self.behavior_type.to_alipay_dict()
            else:
                params['behavior_type'] = self.behavior_type
        if self.device_sn:
            if hasattr(self.device_sn, 'to_alipay_dict'):
                params['device_sn'] = self.device_sn.to_alipay_dict()
            else:
                params['device_sn'] = self.device_sn
        if self.imei:
            if hasattr(self.imei, 'to_alipay_dict'):
                params['imei'] = self.imei.to_alipay_dict()
            else:
                params['imei'] = self.imei
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceIotMdeviceprodBehaviorlogBatchqueryModel()
        if 'behavior_type' in d:
            o.behavior_type = d['behavior_type']
        if 'device_sn' in d:
            o.device_sn = d['device_sn']
        if 'imei' in d:
            o.imei = d['imei']
        if 'item_id' in d:
            o.item_id = d['item_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiMarketingDataBizadviserMyreportQueryModel(object):

    def __init__(self):
        self._req_parameters = None
        self._uniq_key = None
        self._user_id = None

    @property
    def req_parameters(self):
        return self._req_parameters

    @req_parameters.setter
    def req_parameters(self, value):
        self._req_parameters = value
    @property
    def uniq_key(self):
        return self._uniq_key

    @uniq_key.setter
    def uniq_key(self, value):
        self._uniq_key = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.req_parameters:
            if hasattr(self.req_parameters, 'to_alipay_dict'):
                params['req_parameters'] = self.req_parameters.to_alipay_dict()
            else:
                params['req_parameters'] = self.req_parameters
        if self.uniq_key:
            if hasattr(self.uniq_key, 'to_alipay_dict'):
                params['uniq_key'] = self.uniq_key.to_alipay_dict()
            else:
                params['uniq_key'] = self.uniq_key
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiMarketingDataBizadviserMyreportQueryModel()
        if 'req_parameters' in d:
            o.req_parameters = d['req_parameters']
        if 'uniq_key' in d:
            o.uniq_key = d['uniq_key']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class ZhimaCustomerContractRecordSyncResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaCustomerContractRecordSyncResponse, self).__init__()
        self._record_no = None

    @property
    def record_no(self):
        return self._record_no

    @record_no.setter
    def record_no(self, value):
        self._record_no = value

    def parse_response_content(self, response_content):
        response = super(ZhimaCustomerContractRecordSyncResponse, self).parse_response_content(response_content)
        if 'record_no' in response:
            self.record_no = response['record_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ContractOpenApiAttachDTO(object):

    def __init__(self):
        self._file_location = None
        self._file_name = None
        self._file_version = None
        self._pdf_file_location = None

    @property
    def file_location(self):
        return self._file_location

    @file_location.setter
    def file_location(self, value):
        self._file_location = value
    @property
    def file_name(self):
        return self._file_name

    @file_name.setter
    def file_name(self, value):
        self._file_name = value
    @property
    def file_version(self):
        return self._file_version

    @file_version.setter
    def file_version(self, value):
        self._file_version = value
    @property
    def pdf_file_location(self):
        return self._pdf_file_location

    @pdf_file_location.setter
    def pdf_file_location(self, value):
        self._pdf_file_location = value


    def to_alipay_dict(self):
        params = dict()
        if self.file_location:
            if hasattr(self.file_location, 'to_alipay_dict'):
                params['file_location'] = self.file_location.to_alipay_dict()
            else:
                params['file_location'] = self.file_location
        if self.file_name:
            if hasattr(self.file_name, 'to_alipay_dict'):
                params['file_name'] = self.file_name.to_alipay_dict()
            else:
                params['file_name'] = self.file_name
        if self.file_version:
            if hasattr(self.file_version, 'to_alipay_dict'):
                params['file_version'] = self.file_version.to_alipay_dict()
            else:
                params['file_version'] = self.file_version
        if self.pdf_file_location:
            if hasattr(self.pdf_file_location, 'to_alipay_dict'):
                params['pdf_file_location'] = self.pdf_file_location.to_alipay_dict()
            else:
                params['pdf_file_location'] = self.pdf_file_location
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ContractOpenApiAttachDTO()
        if 'file_location' in d:
            o.file_location = d['file_location']
        if 'file_name' in d:
            o.file_name = d['file_name']
        if 'file_version' in d:
            o.file_version = d['file_version']
        if 'pdf_file_location' in d:
            o.pdf_file_location = d['pdf_file_location']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoTrafficCodeVerifyModel(object):

    def __init__(self):
        self._cert_service_type = None
        self._cert_type = None
        self._offline_cert = None
        self._parse_mode = None
        self._user_id = None

    @property
    def cert_service_type(self):
        return self._cert_service_type

    @cert_service_type.setter
    def cert_service_type(self, value):
        self._cert_service_type = value
    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def offline_cert(self):
        return self._offline_cert

    @offline_cert.setter
    def offline_cert(self, value):
        self._offline_cert = value
    @property
    def parse_mode(self):
        return self._parse_mode

    @parse_mode.setter
    def parse_mode(self, value):
        self._parse_mode = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.cert_service_type:
            if hasattr(self.cert_service_type, 'to_alipay_dict'):
                params['cert_service_type'] = self.cert_service_type.to_alipay_dict()
            else:
                params['cert_service_type'] = self.cert_service_type
        if self.cert_type:
            if hasattr(self.cert_type, 'to_alipay_dict'):
                params['cert_type'] = self.cert_type.to_alipay_dict()
            else:
                params['cert_type'] = self.cert_type
        if self.offline_cert:
            if hasattr(self.offline_cert, 'to_alipay_dict'):
                params['offline_cert'] = self.offline_cert.to_alipay_dict()
            else:
                params['offline_cert'] = self.offline_cert
        if self.parse_mode:
            if hasattr(self.parse_mode, 'to_alipay_dict'):
                params['parse_mode'] = self.parse_mode.to_alipay_dict()
            else:
                params['parse_mode'] = self.parse_mode
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoTrafficCodeVerifyModel()
        if 'cert_service_type' in d:
            o.cert_service_type = d['cert_service_type']
        if 'cert_type' in d:
            o.cert_type = d['cert_type']
        if 'offline_cert' in d:
            o.offline_cert = d['offline_cert']
        if 'parse_mode' in d:
            o.parse_mode = d['parse_mode']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BudgetVO(object):

    def __init__(self):
        self._need_repay_total = None
        self._nom_int = None
        self._nom_prin = None
        self._ovd_int = None
        self._ovd_int_pen_int = None
        self._ovd_prin = None
        self._ovd_prin_pen_int = None

    @property
    def need_repay_total(self):
        return self._need_repay_total

    @need_repay_total.setter
    def need_repay_total(self, value):
        self._need_repay_total = value
    @property
    def nom_int(self):
        return self._nom_int

    @nom_int.setter
    def nom_int(self, value):
        self._nom_int = value
    @property
    def nom_prin(self):
        return self._nom_prin

    @nom_prin.setter
    def nom_prin(self, value):
        self._nom_prin = value
    @property
    def ovd_int(self):
        return self._ovd_int

    @ovd_int.setter
    def ovd_int(self, value):
        self._ovd_int = value
    @property
    def ovd_int_pen_int(self):
        return self._ovd_int_pen_int

    @ovd_int_pen_int.setter
    def ovd_int_pen_int(self, value):
        self._ovd_int_pen_int = value
    @property
    def ovd_prin(self):
        return self._ovd_prin

    @ovd_prin.setter
    def ovd_prin(self, value):
        self._ovd_prin = value
    @property
    def ovd_prin_pen_int(self):
        return self._ovd_prin_pen_int

    @ovd_prin_pen_int.setter
    def ovd_prin_pen_int(self, value):
        self._ovd_prin_pen_int = value


    def to_alipay_dict(self):
        params = dict()
        if self.need_repay_total:
            if hasattr(self.need_repay_total, 'to_alipay_dict'):
                params['need_repay_total'] = self.need_repay_total.to_alipay_dict()
            else:
                params['need_repay_total'] = self.need_repay_total
        if self.nom_int:
            if hasattr(self.nom_int, 'to_alipay_dict'):
                params['nom_int'] = self.nom_int.to_alipay_dict()
            else:
                params['nom_int'] = self.nom_int
        if self.nom_prin:
            if hasattr(self.nom_prin, 'to_alipay_dict'):
                params['nom_prin'] = self.nom_prin.to_alipay_dict()
            else:
                params['nom_prin'] = self.nom_prin
        if self.ovd_int:
            if hasattr(self.ovd_int, 'to_alipay_dict'):
                params['ovd_int'] = self.ovd_int.to_alipay_dict()
            else:
                params['ovd_int'] = self.ovd_int
        if self.ovd_int_pen_int:
            if hasattr(self.ovd_int_pen_int, 'to_alipay_dict'):
                params['ovd_int_pen_int'] = self.ovd_int_pen_int.to_alipay_dict()
            else:
                params['ovd_int_pen_int'] = self.ovd_int_pen_int
        if self.ovd_prin:
            if hasattr(self.ovd_prin, 'to_alipay_dict'):
                params['ovd_prin'] = self.ovd_prin.to_alipay_dict()
            else:
                params['ovd_prin'] = self.ovd_prin
        if self.ovd_prin_pen_int:
            if hasattr(self.ovd_prin_pen_int, 'to_alipay_dict'):
                params['ovd_prin_pen_int'] = self.ovd_prin_pen_int.to_alipay_dict()
            else:
                params['ovd_prin_pen_int'] = self.ovd_prin_pen_int
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BudgetVO()
        if 'need_repay_total' in d:
            o.need_repay_total = d['need_repay_total']
        if 'nom_int' in d:
            o.nom_int = d['nom_int']
        if 'nom_prin' in d:
            o.nom_prin = d['nom_prin']
        if 'ovd_int' in d:
            o.ovd_int = d['ovd_int']
        if 'ovd_int_pen_int' in d:
            o.ovd_int_pen_int = d['ovd_int_pen_int']
        if 'ovd_prin' in d:
            o.ovd_prin = d['ovd_prin']
        if 'ovd_prin_pen_int' in d:
            o.ovd_prin_pen_int = d['ovd_prin_pen_int']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.QuestInstanceDO import QuestInstanceDO


class AlipaySocialBaseQuestInstanceAddResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySocialBaseQuestInstanceAddResponse, self).__init__()
        self._instance = None

    @property
    def instance(self):
        return self._instance

    @instance.setter
    def instance(self, value):
        if isinstance(value, QuestInstanceDO):
            self._instance = value
        else:
            self._instance = QuestInstanceDO.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipaySocialBaseQuestInstanceAddResponse, self).parse_response_content(response_content)
        if 'instance' in response:
            self.instance = response['instance']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayDataDataserviceBillDingstaffbizorderQueryModel(object):

    def __init__(self):
        self._biz_trans_id = None
        self._biz_type = None
        self._direction = None
        self._gmt_date_end = None
        self._gmt_date_start = None
        self._last_id = None
        self._order_id = None
        self._page_size = None
        self._title = None
        self._virtual_user_id = None

    @property
    def biz_trans_id(self):
        return self._biz_trans_id

    @biz_trans_id.setter
    def biz_trans_id(self, value):
        self._biz_trans_id = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def direction(self):
        return self._direction

    @direction.setter
    def direction(self, value):
        self._direction = value
    @property
    def gmt_date_end(self):
        return self._gmt_date_end

    @gmt_date_end.setter
    def gmt_date_end(self, value):
        self._gmt_date_end = value
    @property
    def gmt_date_start(self):
        return self._gmt_date_start

    @gmt_date_start.setter
    def gmt_date_start(self, value):
        self._gmt_date_start = value
    @property
    def last_id(self):
        return self._last_id

    @last_id.setter
    def last_id(self, value):
        self._last_id = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value
    @property
    def virtual_user_id(self):
        return self._virtual_user_id

    @virtual_user_id.setter
    def virtual_user_id(self, value):
        self._virtual_user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_trans_id:
            if hasattr(self.biz_trans_id, 'to_alipay_dict'):
                params['biz_trans_id'] = self.biz_trans_id.to_alipay_dict()
            else:
                params['biz_trans_id'] = self.biz_trans_id
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.direction:
            if hasattr(self.direction, 'to_alipay_dict'):
                params['direction'] = self.direction.to_alipay_dict()
            else:
                params['direction'] = self.direction
        if self.gmt_date_end:
            if hasattr(self.gmt_date_end, 'to_alipay_dict'):
                params['gmt_date_end'] = self.gmt_date_end.to_alipay_dict()
            else:
                params['gmt_date_end'] = self.gmt_date_end
        if self.gmt_date_start:
            if hasattr(self.gmt_date_start, 'to_alipay_dict'):
                params['gmt_date_start'] = self.gmt_date_start.to_alipay_dict()
            else:
                params['gmt_date_start'] = self.gmt_date_start
        if self.last_id:
            if hasattr(self.last_id, 'to_alipay_dict'):
                params['last_id'] = self.last_id.to_alipay_dict()
            else:
                params['last_id'] = self.last_id
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        if self.virtual_user_id:
            if hasattr(self.virtual_user_id, 'to_alipay_dict'):
                params['virtual_user_id'] = self.virtual_user_id.to_alipay_dict()
            else:
                params['virtual_user_id'] = self.virtual_user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDataDataserviceBillDingstaffbizorderQueryModel()
        if 'biz_trans_id' in d:
            o.biz_trans_id = d['biz_trans_id']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'direction' in d:
            o.direction = d['direction']
        if 'gmt_date_end' in d:
            o.gmt_date_end = d['gmt_date_end']
        if 'gmt_date_start' in d:
            o.gmt_date_start = d['gmt_date_start']
        if 'last_id' in d:
            o.last_id = d['last_id']
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'title' in d:
            o.title = d['title']
        if 'virtual_user_id' in d:
            o.virtual_user_id = d['virtual_user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayDataDataserviceAdPromotepageBatchqueryModel(object):

    def __init__(self):
        self._biz_token = None
        self._page_no = None
        self._page_size = None
        self._principal_tag = None
        self._type = None

    @property
    def biz_token(self):
        return self._biz_token

    @biz_token.setter
    def biz_token(self, value):
        self._biz_token = value
    @property
    def page_no(self):
        return self._page_no

    @page_no.setter
    def page_no(self, value):
        self._page_no = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def principal_tag(self):
        return self._principal_tag

    @principal_tag.setter
    def principal_tag(self, value):
        self._principal_tag = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_token:
            if hasattr(self.biz_token, 'to_alipay_dict'):
                params['biz_token'] = self.biz_token.to_alipay_dict()
            else:
                params['biz_token'] = self.biz_token
        if self.page_no:
            if hasattr(self.page_no, 'to_alipay_dict'):
                params['page_no'] = self.page_no.to_alipay_dict()
            else:
                params['page_no'] = self.page_no
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.principal_tag:
            if hasattr(self.principal_tag, 'to_alipay_dict'):
                params['principal_tag'] = self.principal_tag.to_alipay_dict()
            else:
                params['principal_tag'] = self.principal_tag
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDataDataserviceAdPromotepageBatchqueryModel()
        if 'biz_token' in d:
            o.biz_token = d['biz_token']
        if 'page_no' in d:
            o.page_no = d['page_no']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'principal_tag' in d:
            o.principal_tag = d['principal_tag']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceKidsMsgSceneSendModel(object):

    def __init__(self):
        self._biz_code = None
        self._biz_data = None
        self._biz_time = None
        self._out_biz_no = None
        self._template_code = None
        self._template_code_version = None

    @property
    def biz_code(self):
        return self._biz_code

    @biz_code.setter
    def biz_code(self, value):
        self._biz_code = value
    @property
    def biz_data(self):
        return self._biz_data

    @biz_data.setter
    def biz_data(self, value):
        self._biz_data = value
    @property
    def biz_time(self):
        return self._biz_time

    @biz_time.setter
    def biz_time(self, value):
        self._biz_time = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def template_code(self):
        return self._template_code

    @template_code.setter
    def template_code(self, value):
        self._template_code = value
    @property
    def template_code_version(self):
        return self._template_code_version

    @template_code_version.setter
    def template_code_version(self, value):
        self._template_code_version = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_code:
            if hasattr(self.biz_code, 'to_alipay_dict'):
                params['biz_code'] = self.biz_code.to_alipay_dict()
            else:
                params['biz_code'] = self.biz_code
        if self.biz_data:
            if hasattr(self.biz_data, 'to_alipay_dict'):
                params['biz_data'] = self.biz_data.to_alipay_dict()
            else:
                params['biz_data'] = self.biz_data
        if self.biz_time:
            if hasattr(self.biz_time, 'to_alipay_dict'):
                params['biz_time'] = self.biz_time.to_alipay_dict()
            else:
                params['biz_time'] = self.biz_time
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.template_code:
            if hasattr(self.template_code, 'to_alipay_dict'):
                params['template_code'] = self.template_code.to_alipay_dict()
            else:
                params['template_code'] = self.template_code
        if self.template_code_version:
            if hasattr(self.template_code_version, 'to_alipay_dict'):
                params['template_code_version'] = self.template_code_version.to_alipay_dict()
            else:
                params['template_code_version'] = self.template_code_version
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceKidsMsgSceneSendModel()
        if 'biz_code' in d:
            o.biz_code = d['biz_code']
        if 'biz_data' in d:
            o.biz_data = d['biz_data']
        if 'biz_time' in d:
            o.biz_time = d['biz_time']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'template_code' in d:
            o.template_code = d['template_code']
        if 'template_code_version' in d:
            o.template_code_version = d['template_code_version']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayUserElectronicidUserQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserElectronicidUserQueryResponse, self).__init__()
        self._address = None
        self._birthday = None
        self._cert_no = None
        self._cert_picture = None
        self._gender = None
        self._name = None
        self._nation = None
        self._picture = None
        self._secret_key = None
        self._sign_org = None
        self._valid_begin_date = None
        self._valid_end_date = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def birthday(self):
        return self._birthday

    @birthday.setter
    def birthday(self, value):
        self._birthday = value
    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def cert_picture(self):
        return self._cert_picture

    @cert_picture.setter
    def cert_picture(self, value):
        self._cert_picture = value
    @property
    def gender(self):
        return self._gender

    @gender.setter
    def gender(self, value):
        self._gender = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def nation(self):
        return self._nation

    @nation.setter
    def nation(self, value):
        self._nation = value
    @property
    def picture(self):
        return self._picture

    @picture.setter
    def picture(self, value):
        self._picture = value
    @property
    def secret_key(self):
        return self._secret_key

    @secret_key.setter
    def secret_key(self, value):
        self._secret_key = value
    @property
    def sign_org(self):
        return self._sign_org

    @sign_org.setter
    def sign_org(self, value):
        self._sign_org = value
    @property
    def valid_begin_date(self):
        return self._valid_begin_date

    @valid_begin_date.setter
    def valid_begin_date(self, value):
        self._valid_begin_date = value
    @property
    def valid_end_date(self):
        return self._valid_end_date

    @valid_end_date.setter
    def valid_end_date(self, value):
        self._valid_end_date = value

    def parse_response_content(self, response_content):
        response = super(AlipayUserElectronicidUserQueryResponse, self).parse_response_content(response_content)
        if 'address' in response:
            self.address = response['address']
        if 'birthday' in response:
            self.birthday = response['birthday']
        if 'cert_no' in response:
            self.cert_no = response['cert_no']
        if 'cert_picture' in response:
            self.cert_picture = response['cert_picture']
        if 'gender' in response:
            self.gender = response['gender']
        if 'name' in response:
            self.name = response['name']
        if 'nation' in response:
            self.nation = response['nation']
        if 'picture' in response:
            self.picture = response['picture']
        if 'secret_key' in response:
            self.secret_key = response['secret_key']
        if 'sign_org' in response:
            self.sign_org = response['sign_org']
        if 'valid_begin_date' in response:
            self.valid_begin_date = response['valid_begin_date']
        if 'valid_end_date' in response:
            self.valid_end_date = response['valid_end_date']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiTradeTicketTicketcodeCancelModel(object):

    def __init__(self):
        self._code_type = None
        self._order_no = None
        self._quantity = None
        self._request_biz_no = None
        self._request_id = None
        self._ticket_code = None

    @property
    def code_type(self):
        return self._code_type

    @code_type.setter
    def code_type(self, value):
        self._code_type = value
    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value
    @property
    def quantity(self):
        return self._quantity

    @quantity.setter
    def quantity(self, value):
        self._quantity = value
    @property
    def request_biz_no(self):
        return self._request_biz_no

    @request_biz_no.setter
    def request_biz_no(self, value):
        self._request_biz_no = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def ticket_code(self):
        return self._ticket_code

    @ticket_code.setter
    def ticket_code(self, value):
        self._ticket_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.code_type:
            if hasattr(self.code_type, 'to_alipay_dict'):
                params['code_type'] = self.code_type.to_alipay_dict()
            else:
                params['code_type'] = self.code_type
        if self.order_no:
            if hasattr(self.order_no, 'to_alipay_dict'):
                params['order_no'] = self.order_no.to_alipay_dict()
            else:
                params['order_no'] = self.order_no
        if self.quantity:
            if hasattr(self.quantity, 'to_alipay_dict'):
                params['quantity'] = self.quantity.to_alipay_dict()
            else:
                params['quantity'] = self.quantity
        if self.request_biz_no:
            if hasattr(self.request_biz_no, 'to_alipay_dict'):
                params['request_biz_no'] = self.request_biz_no.to_alipay_dict()
            else:
                params['request_biz_no'] = self.request_biz_no
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        if self.ticket_code:
            if hasattr(self.ticket_code, 'to_alipay_dict'):
                params['ticket_code'] = self.ticket_code.to_alipay_dict()
            else:
                params['ticket_code'] = self.ticket_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiTradeTicketTicketcodeCancelModel()
        if 'code_type' in d:
            o.code_type = d['code_type']
        if 'order_no' in d:
            o.order_no = d['order_no']
        if 'quantity' in d:
            o.quantity = d['quantity']
        if 'request_biz_no' in d:
            o.request_biz_no = d['request_biz_no']
        if 'request_id' in d:
            o.request_id = d['request_id']
        if 'ticket_code' in d:
            o.ticket_code = d['ticket_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ModelQueryParam import ModelQueryParam


class AlipayMarketingDataModelQueryModel(object):

    def __init__(self):
        self._model_query_param = None
        self._model_uk = None

    @property
    def model_query_param(self):
        return self._model_query_param

    @model_query_param.setter
    def model_query_param(self, value):
        if isinstance(value, list):
            self._model_query_param = list()
            for i in value:
                if isinstance(i, ModelQueryParam):
                    self._model_query_param.append(i)
                else:
                    self._model_query_param.append(ModelQueryParam.from_alipay_dict(i))
    @property
    def model_uk(self):
        return self._model_uk

    @model_uk.setter
    def model_uk(self, value):
        self._model_uk = value


    def to_alipay_dict(self):
        params = dict()
        if self.model_query_param:
            if isinstance(self.model_query_param, list):
                for i in range(0, len(self.model_query_param)):
                    element = self.model_query_param[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.model_query_param[i] = element.to_alipay_dict()
            if hasattr(self.model_query_param, 'to_alipay_dict'):
                params['model_query_param'] = self.model_query_param.to_alipay_dict()
            else:
                params['model_query_param'] = self.model_query_param
        if self.model_uk:
            if hasattr(self.model_uk, 'to_alipay_dict'):
                params['model_uk'] = self.model_uk.to_alipay_dict()
            else:
                params['model_uk'] = self.model_uk
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingDataModelQueryModel()
        if 'model_query_param' in d:
            o.model_query_param = d['model_query_param']
        if 'model_uk' in d:
            o.model_uk = d['model_uk']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayFundInstcardOpenQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundInstcardOpenQueryResponse, self).__init__()
        self._account_name = None
        self._account_no = None
        self._account_status = None
        self._inst_id = None
        self._inst_name = None

    @property
    def account_name(self):
        return self._account_name

    @account_name.setter
    def account_name(self, value):
        self._account_name = value
    @property
    def account_no(self):
        return self._account_no

    @account_no.setter
    def account_no(self, value):
        self._account_no = value
    @property
    def account_status(self):
        return self._account_status

    @account_status.setter
    def account_status(self, value):
        self._account_status = value
    @property
    def inst_id(self):
        return self._inst_id

    @inst_id.setter
    def inst_id(self, value):
        self._inst_id = value
    @property
    def inst_name(self):
        return self._inst_name

    @inst_name.setter
    def inst_name(self, value):
        self._inst_name = value

    def parse_response_content(self, response_content):
        response = super(AlipayFundInstcardOpenQueryResponse, self).parse_response_content(response_content)
        if 'account_name' in response:
            self.account_name = response['account_name']
        if 'account_no' in response:
            self.account_no = response['account_no']
        if 'account_status' in response:
            self.account_status = response['account_status']
        if 'inst_id' in response:
            self.inst_id = response['inst_id']
        if 'inst_name' in response:
            self.inst_name = response['inst_name']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PosCookDishCateModel(object):

    def __init__(self):
        self._cate_dish_num = None
        self._cate_id = None
        self._cate_name = None
        self._cate_sort = None

    @property
    def cate_dish_num(self):
        return self._cate_dish_num

    @cate_dish_num.setter
    def cate_dish_num(self, value):
        self._cate_dish_num = value
    @property
    def cate_id(self):
        return self._cate_id

    @cate_id.setter
    def cate_id(self, value):
        self._cate_id = value
    @property
    def cate_name(self):
        return self._cate_name

    @cate_name.setter
    def cate_name(self, value):
        self._cate_name = value
    @property
    def cate_sort(self):
        return self._cate_sort

    @cate_sort.setter
    def cate_sort(self, value):
        self._cate_sort = value


    def to_alipay_dict(self):
        params = dict()
        if self.cate_dish_num:
            if hasattr(self.cate_dish_num, 'to_alipay_dict'):
                params['cate_dish_num'] = self.cate_dish_num.to_alipay_dict()
            else:
                params['cate_dish_num'] = self.cate_dish_num
        if self.cate_id:
            if hasattr(self.cate_id, 'to_alipay_dict'):
                params['cate_id'] = self.cate_id.to_alipay_dict()
            else:
                params['cate_id'] = self.cate_id
        if self.cate_name:
            if hasattr(self.cate_name, 'to_alipay_dict'):
                params['cate_name'] = self.cate_name.to_alipay_dict()
            else:
                params['cate_name'] = self.cate_name
        if self.cate_sort:
            if hasattr(self.cate_sort, 'to_alipay_dict'):
                params['cate_sort'] = self.cate_sort.to_alipay_dict()
            else:
                params['cate_sort'] = self.cate_sort
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PosCookDishCateModel()
        if 'cate_dish_num' in d:
            o.cate_dish_num = d['cate_dish_num']
        if 'cate_id' in d:
            o.cate_id = d['cate_id']
        if 'cate_name' in d:
            o.cate_name = d['cate_name']
        if 'cate_sort' in d:
            o.cate_sort = d['cate_sort']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiMerchantOperatorRoleQueryModel(object):

    def __init__(self):
        self._auth_code = None
        self._role_id = None

    @property
    def auth_code(self):
        return self._auth_code

    @auth_code.setter
    def auth_code(self, value):
        self._auth_code = value
    @property
    def role_id(self):
        return self._role_id

    @role_id.setter
    def role_id(self, value):
        self._role_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.auth_code:
            if hasattr(self.auth_code, 'to_alipay_dict'):
                params['auth_code'] = self.auth_code.to_alipay_dict()
            else:
                params['auth_code'] = self.auth_code
        if self.role_id:
            if hasattr(self.role_id, 'to_alipay_dict'):
                params['role_id'] = self.role_id.to_alipay_dict()
            else:
                params['role_id'] = self.role_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiMerchantOperatorRoleQueryModel()
        if 'auth_code' in d:
            o.auth_code = d['auth_code']
        if 'role_id' in d:
            o.role_id = d['role_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.TemplateEvoucherDTO import TemplateEvoucherDTO
from alipay.aop.api.domain.TemplateFileDTO import TemplateFileDTO
from alipay.aop.api.domain.TemplateImageDTO import TemplateImageDTO
from alipay.aop.api.domain.TemplateMerchantDTO import TemplateMerchantDTO
from alipay.aop.api.domain.TemplatePlatformDTO import TemplatePlatformDTO
from alipay.aop.api.domain.TemplateStyleDTO import TemplateStyleDTO


class AlipayUserPassTemplateQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserPassTemplateQueryResponse, self).__init__()
        self._evoucher_info = None
        self._file_info = None
        self._image = None
        self._merchant = None
        self._platform = None
        self._style = None

    @property
    def evoucher_info(self):
        return self._evoucher_info

    @evoucher_info.setter
    def evoucher_info(self, value):
        if isinstance(value, TemplateEvoucherDTO):
            self._evoucher_info = value
        else:
            self._evoucher_info = TemplateEvoucherDTO.from_alipay_dict(value)
    @property
    def file_info(self):
        return self._file_info

    @file_info.setter
    def file_info(self, value):
        if isinstance(value, TemplateFileDTO):
            self._file_info = value
        else:
            self._file_info = TemplateFileDTO.from_alipay_dict(value)
    @property
    def image(self):
        return self._image

    @image.setter
    def image(self, value):
        if isinstance(value, TemplateImageDTO):
            self._image = value
        else:
            self._image = TemplateImageDTO.from_alipay_dict(value)
    @property
    def merchant(self):
        return self._merchant

    @merchant.setter
    def merchant(self, value):
        if isinstance(value, TemplateMerchantDTO):
            self._merchant = value
        else:
            self._merchant = TemplateMerchantDTO.from_alipay_dict(value)
    @property
    def platform(self):
        return self._platform

    @platform.setter
    def platform(self, value):
        if isinstance(value, TemplatePlatformDTO):
            self._platform = value
        else:
            self._platform = TemplatePlatformDTO.from_alipay_dict(value)
    @property
    def style(self):
        return self._style

    @style.setter
    def style(self, value):
        if isinstance(value, TemplateStyleDTO):
            self._style = value
        else:
            self._style = TemplateStyleDTO.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayUserPassTemplateQueryResponse, self).parse_response_content(response_content)
        if 'evoucher_info' in response:
            self.evoucher_info = response['evoucher_info']
        if 'file_info' in response:
            self.file_info = response['file_info']
        if 'image' in response:
            self.image = response['image']
        if 'merchant' in response:
            self.merchant = response['merchant']
        if 'platform' in response:
            self.platform = response['platform']
        if 'style' in response:
            self.style = response['style']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.FengdieSitesOwner import FengdieSitesOwner
from alipay.aop.api.domain.FengdieSitesPageModel import FengdieSitesPageModel


class FengdieSitesQueryRespModel(object):

    def __init__(self):
        self._gmt_modified = None
        self._id = None
        self._is_online = None
        self._offline_time = None
        self._owner = None
        self._pages = None
        self._status = None
        self._template_name = None
        self._template_version = None
        self._title = None

    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def is_online(self):
        return self._is_online

    @is_online.setter
    def is_online(self, value):
        self._is_online = value
    @property
    def offline_time(self):
        return self._offline_time

    @offline_time.setter
    def offline_time(self, value):
        self._offline_time = value
    @property
    def owner(self):
        return self._owner

    @owner.setter
    def owner(self, value):
        if isinstance(value, FengdieSitesOwner):
            self._owner = value
        else:
            self._owner = FengdieSitesOwner.from_alipay_dict(value)
    @property
    def pages(self):
        return self._pages

    @pages.setter
    def pages(self, value):
        if isinstance(value, list):
            self._pages = list()
            for i in value:
                if isinstance(i, FengdieSitesPageModel):
                    self._pages.append(i)
                else:
                    self._pages.append(FengdieSitesPageModel.from_alipay_dict(i))
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def template_name(self):
        return self._template_name

    @template_name.setter
    def template_name(self, value):
        self._template_name = value
    @property
    def template_version(self):
        return self._template_version

    @template_version.setter
    def template_version(self, value):
        self._template_version = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value


    def to_alipay_dict(self):
        params = dict()
        if self.gmt_modified:
            if hasattr(self.gmt_modified, 'to_alipay_dict'):
                params['gmt_modified'] = self.gmt_modified.to_alipay_dict()
            else:
                params['gmt_modified'] = self.gmt_modified
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.is_online:
            if hasattr(self.is_online, 'to_alipay_dict'):
                params['is_online'] = self.is_online.to_alipay_dict()
            else:
                params['is_online'] = self.is_online
        if self.offline_time:
            if hasattr(self.offline_time, 'to_alipay_dict'):
                params['offline_time'] = self.offline_time.to_alipay_dict()
            else:
                params['offline_time'] = self.offline_time
        if self.owner:
            if hasattr(self.owner, 'to_alipay_dict'):
                params['owner'] = self.owner.to_alipay_dict()
            else:
                params['owner'] = self.owner
        if self.pages:
            if isinstance(self.pages, list):
                for i in range(0, len(self.pages)):
                    element = self.pages[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.pages[i] = element.to_alipay_dict()
            if hasattr(self.pages, 'to_alipay_dict'):
                params['pages'] = self.pages.to_alipay_dict()
            else:
                params['pages'] = self.pages
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.template_name:
            if hasattr(self.template_name, 'to_alipay_dict'):
                params['template_name'] = self.template_name.to_alipay_dict()
            else:
                params['template_name'] = self.template_name
        if self.template_version:
            if hasattr(self.template_version, 'to_alipay_dict'):
                params['template_version'] = self.template_version.to_alipay_dict()
            else:
                params['template_version'] = self.template_version
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = FengdieSitesQueryRespModel()
        if 'gmt_modified' in d:
            o.gmt_modified = d['gmt_modified']
        if 'id' in d:
            o.id = d['id']
        if 'is_online' in d:
            o.is_online = d['is_online']
        if 'offline_time' in d:
            o.offline_time = d['offline_time']
        if 'owner' in d:
            o.owner = d['owner']
        if 'pages' in d:
            o.pages = d['pages']
        if 'status' in d:
            o.status = d['status']
        if 'template_name' in d:
            o.template_name = d['template_name']
        if 'template_version' in d:
            o.template_version = d['template_version']
        if 'title' in d:
            o.title = d['title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySecurityRiskAntifraudBatchqueryModel(object):

    def __init__(self):
        self._company_list = None
        self._partner_name = None
        self._staff_list = None

    @property
    def company_list(self):
        return self._company_list

    @company_list.setter
    def company_list(self, value):
        if isinstance(value, list):
            self._company_list = list()
            for i in value:
                self._company_list.append(i)
    @property
    def partner_name(self):
        return self._partner_name

    @partner_name.setter
    def partner_name(self, value):
        self._partner_name = value
    @property
    def staff_list(self):
        return self._staff_list

    @staff_list.setter
    def staff_list(self, value):
        if isinstance(value, list):
            self._staff_list = list()
            for i in value:
                self._staff_list.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.company_list:
            if isinstance(self.company_list, list):
                for i in range(0, len(self.company_list)):
                    element = self.company_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.company_list[i] = element.to_alipay_dict()
            if hasattr(self.company_list, 'to_alipay_dict'):
                params['company_list'] = self.company_list.to_alipay_dict()
            else:
                params['company_list'] = self.company_list
        if self.partner_name:
            if hasattr(self.partner_name, 'to_alipay_dict'):
                params['partner_name'] = self.partner_name.to_alipay_dict()
            else:
                params['partner_name'] = self.partner_name
        if self.staff_list:
            if isinstance(self.staff_list, list):
                for i in range(0, len(self.staff_list)):
                    element = self.staff_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.staff_list[i] = element.to_alipay_dict()
            if hasattr(self.staff_list, 'to_alipay_dict'):
                params['staff_list'] = self.staff_list.to_alipay_dict()
            else:
                params['staff_list'] = self.staff_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySecurityRiskAntifraudBatchqueryModel()
        if 'company_list' in d:
            o.company_list = d['company_list']
        if 'partner_name' in d:
            o.partner_name = d['partner_name']
        if 'staff_list' in d:
            o.staff_list = d['staff_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ActivityPlanInfo import ActivityPlanInfo


class KoubeiMarketingCampaignMallInviteQueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiMarketingCampaignMallInviteQueryResponse, self).__init__()
        self._activity_plan_info_list = None

    @property
    def activity_plan_info_list(self):
        return self._activity_plan_info_list

    @activity_plan_info_list.setter
    def activity_plan_info_list(self, value):
        if isinstance(value, list):
            self._activity_plan_info_list = list()
            for i in value:
                if isinstance(i, ActivityPlanInfo):
                    self._activity_plan_info_list.append(i)
                else:
                    self._activity_plan_info_list.append(ActivityPlanInfo.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(KoubeiMarketingCampaignMallInviteQueryResponse, self).parse_response_content(response_content)
        if 'activity_plan_info_list' in response:
            self.activity_plan_info_list = response['activity_plan_info_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AdvanceElementsDTO import AdvanceElementsDTO


class InstAccountElementsDTO(object):

    def __init__(self):
        self._advance_elements = None
        self._inst_id = None
        self._sub_account_name = None
        self._sub_account_type = None

    @property
    def advance_elements(self):
        return self._advance_elements

    @advance_elements.setter
    def advance_elements(self, value):
        if isinstance(value, AdvanceElementsDTO):
            self._advance_elements = value
        else:
            self._advance_elements = AdvanceElementsDTO.from_alipay_dict(value)
    @property
    def inst_id(self):
        return self._inst_id

    @inst_id.setter
    def inst_id(self, value):
        self._inst_id = value
    @property
    def sub_account_name(self):
        return self._sub_account_name

    @sub_account_name.setter
    def sub_account_name(self, value):
        self._sub_account_name = value
    @property
    def sub_account_type(self):
        return self._sub_account_type

    @sub_account_type.setter
    def sub_account_type(self, value):
        self._sub_account_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.advance_elements:
            if hasattr(self.advance_elements, 'to_alipay_dict'):
                params['advance_elements'] = self.advance_elements.to_alipay_dict()
            else:
                params['advance_elements'] = self.advance_elements
        if self.inst_id:
            if hasattr(self.inst_id, 'to_alipay_dict'):
                params['inst_id'] = self.inst_id.to_alipay_dict()
            else:
                params['inst_id'] = self.inst_id
        if self.sub_account_name:
            if hasattr(self.sub_account_name, 'to_alipay_dict'):
                params['sub_account_name'] = self.sub_account_name.to_alipay_dict()
            else:
                params['sub_account_name'] = self.sub_account_name
        if self.sub_account_type:
            if hasattr(self.sub_account_type, 'to_alipay_dict'):
                params['sub_account_type'] = self.sub_account_type.to_alipay_dict()
            else:
                params['sub_account_type'] = self.sub_account_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InstAccountElementsDTO()
        if 'advance_elements' in d:
            o.advance_elements = d['advance_elements']
        if 'inst_id' in d:
            o.inst_id = d['inst_id']
        if 'sub_account_name' in d:
            o.sub_account_name = d['sub_account_name']
        if 'sub_account_type' in d:
            o.sub_account_type = d['sub_account_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CommentReplyOpenModel(object):

    def __init__(self):
        self._content = None
        self._operator_id = None
        self._reply_publish_time = None

    @property
    def content(self):
        return self._content

    @content.setter
    def content(self, value):
        self._content = value
    @property
    def operator_id(self):
        return self._operator_id

    @operator_id.setter
    def operator_id(self, value):
        self._operator_id = value
    @property
    def reply_publish_time(self):
        return self._reply_publish_time

    @reply_publish_time.setter
    def reply_publish_time(self, value):
        self._reply_publish_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.content:
            if hasattr(self.content, 'to_alipay_dict'):
                params['content'] = self.content.to_alipay_dict()
            else:
                params['content'] = self.content
        if self.operator_id:
            if hasattr(self.operator_id, 'to_alipay_dict'):
                params['operator_id'] = self.operator_id.to_alipay_dict()
            else:
                params['operator_id'] = self.operator_id
        if self.reply_publish_time:
            if hasattr(self.reply_publish_time, 'to_alipay_dict'):
                params['reply_publish_time'] = self.reply_publish_time.to_alipay_dict()
            else:
                params['reply_publish_time'] = self.reply_publish_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CommentReplyOpenModel()
        if 'content' in d:
            o.content = d['content']
        if 'operator_id' in d:
            o.operator_id = d['operator_id']
        if 'reply_publish_time' in d:
            o.reply_publish_time = d['reply_publish_time']
        return o


